@@ -15,18 +15,19 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: wordlist.cpp 250556 2003-09-12 18:02:28Z binner $
-
-#include <qregexp.h>
-#include <qdir.h>
-
-#include <kapplication.h>
-#include <kstandarddirs.h>
-#include <kprogress.h>
-#include <klocale.h>
+// $Id: wordlist.cpp 708922 2007-09-06 02:06:26Z amth $
 
 #include "wordlist.h"
 
+#include <QtCore/QRegExp>
+#include <QtCore/QDir>
+#include <QtCore/QTextStream>
+
+#include <kstandarddirs.h>
+#include <kprogressdialog.h>
+#include <klocale.h>
+#include <kapplication.h>
+
 namespace WordList {
 void addWords (WordMap &map, QString line);
 
@@ -48,12 +49,12 @@ bool XMLParser::fatalError (const QXmlParseException &) {
    return false;
 }
 
-QString XMLParser::errorString() {
+QString XMLParser::errorString() const {
    return "";
 }
 
 bool XMLParser::startDocument() {
-   text = QString::null;
+   text.clear();
    return true;
 }
 
@@ -63,7 +64,7 @@ bool XMLParser::startElement (const QString &, const QString &,
 {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = QString::null;
+      text.clear();
    }
    return true;
 }
@@ -76,7 +77,7 @@ bool XMLParser::characters (const QString &ch) {
 bool XMLParser::ignorableWhitespace (const QString &) {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = QString::null;
+      text.clear();
    }
    return true;
 }
@@ -86,7 +87,7 @@ bool XMLParser::endElement (const QString &, const QString &,
 {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = QString::null;
+      text.clear();
    }
    return true;
 }
@@ -94,7 +95,7 @@ bool XMLParser::endElement (const QString &, const QString &,
 bool XMLParser::endDocument() {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = QString::null;
+      text.clear();
    }
    return true;
 }
@@ -106,28 +107,28 @@ WordMap XMLParser::getList() {
 /***************************************************************************/
 
 KProgressDialog *progressDialog() {
-   KProgressDialog *pdlg = new KProgressDialog(0, "progressDialog", i18n("Creating Word List"), i18n("Parsing the KDE documentation..."), false);
+   KProgressDialog *pdlg = new KProgressDialog(0,  i18n("Creating Word List"), i18n("Parsing the KDE documentation..."), false);
    pdlg->setAllowCancel (false);
    pdlg->showCancelButton (false);
    pdlg->setAutoReset(false);
    pdlg->setAutoClose(false);
-   pdlg->progressBar()->setTotalSteps(100);
-   pdlg->progressBar()->setProgress(0);
+   pdlg->progressBar()->setMaximum(100);
+   pdlg->progressBar()->setValue(0);
    return pdlg;
 }
 
 bool saveWordList (WordMap map, QString filename) {
    QFile file(filename);
-   if(!file.open(IO_WriteOnly))
+   if(!file.open(QIODevice::WriteOnly))
       return false;
 
    QTextStream stream(&file);
-   stream.setEncoding (QTextStream::UnicodeUTF8);
+   stream.setCodec ("UTF-8");
 
    stream << "WPDictFile\n";
    WordMap::ConstIterator it;
    for (it = map.begin(); it != map.end(); ++it)
-      stream << it.key() << "\t" << it.data() << "\t2\n";
+      stream << it.key() << "\t" << it.value() << "\t2\n";
    file.close();
    return true;
 }
@@ -135,12 +136,12 @@ bool saveWordList (WordMap map, QString filename) {
 /***************************************************************************/
 
 void addWords (WordMap &map, QString line) {
-   QStringList words = QStringList::split(QRegExp("\\W"), line);
-   
+   QStringList words = line.split( QRegExp("\\W"));
+
    QStringList::ConstIterator it;
    for (it = words.begin(); it != words.end(); ++it) {
       if (!(*it).contains(QRegExp("\\d|_"))) {
-         QString key = (*it).lower();
+         QString key = (*it).toLower();
          if (map.contains(key))
             map[key] += 1;
          else
@@ -153,9 +154,9 @@ void addWords (WordMap &map, WordMap add) {
    WordList::WordMap::ConstIterator it;
    for (it = add.begin(); it != add.end(); ++it)
       if (map.contains(it.key()))
-         map[it.key()] += it.data();
+         map[it.key()] += it.value();
       else
-         map[it.key()] = it.data();
+         map[it.key()] = it.value();
 }
 
 void addWordsFromFile (WordMap &map, QString filename, QTextStream::Encoding encoding, QTextCodec *codec) {
@@ -165,15 +166,15 @@ void addWordsFromFile (WordMap &map, QString filename, QTextStream::Encoding enc
    QXmlSimpleReader reader;
    reader.setFeature ("http://trolltech.com/xml/features/report-start-end-entity", true);
    reader.setContentHandler (&parser);
-   
+
    WordMap words;
    if (reader.parse(source)) // try to load the file as an xml-file
       addWords(map, parser.getList());
    else {
       QFile wpdfile(filename);
-      if (wpdfile.open(IO_ReadOnly)) {
+      if (wpdfile.open(QIODevice::ReadOnly)) {
          QTextStream stream(&wpdfile);
-         stream.setEncoding (QTextStream::UnicodeUTF8);
+         stream.setCodec ("UTF-8");
 
          if (!stream.atEnd()) {
             QString s = stream.readLine();
@@ -182,7 +183,7 @@ void addWordsFromFile (WordMap &map, QString filename, QTextStream::Encoding enc
                while (!stream.atEnd()) {
                   QString s = stream.readLine();
                   if (!(s.isNull() || s.isEmpty())) {
-                     QStringList list = QStringList::split("\t", s);
+                     QStringList list = s.split( "\t");
                      bool ok;
                      int weight = list[1].toInt(&ok);
                      if (ok && (weight > 0)) {
@@ -196,7 +197,7 @@ void addWordsFromFile (WordMap &map, QString filename, QTextStream::Encoding enc
             }
             else { // Count the words in an ordinary text file
                QFile file(filename);
-               if (file.open(IO_ReadOnly)) {
+               if (file.open(QIODevice::ReadOnly)) {
                   QTextStream stream(&file);
                   if (codec != 0)
                      stream.setCodec (codec);
@@ -219,7 +220,7 @@ WordMap parseFiles (QStringList files, QTextStream::Encoding encoding, QTextCode
    int progress = 0;
    int steps = files.count();
    int percent = 0;
-   
+
    WordMap map;
    QStringList::ConstIterator it;
    for (progress = 1, it = files.begin(); it != files.end(); ++progress, ++it) {
@@ -227,24 +228,24 @@ WordMap parseFiles (QStringList files, QTextStream::Encoding encoding, QTextCode
 
       if (steps != 0 && progress*100/steps > percent) {
          percent = progress*100/steps;
-         pdlg->progressBar()->setProgress(percent);
-         qApp->processEvents (20);
+         pdlg->progressBar()->setValue(percent);
+         qApp->processEvents (QEventLoop::AllEvents, 20);
       }
    }
    return map;
 }
 
 WordMap mergeFiles  (QMap<QString,int> files, KProgressDialog *pdlg) {
-   pdlg->setLabel (i18n("Merging dictionaries..."));
+   pdlg->setLabelText (i18n("Merging dictionaries..."));
    pdlg->show();
-   qApp->processEvents (20);
-   
+   qApp->processEvents (QEventLoop::AllEvents, 20);
+
    int progress = 0;
    int steps = files.count();
    int percent = 0;
    float totalWeight = 0;
    long long maxWeight = 0;
-   
+
    QMap<QString,float> map;
    QMap<QString,int>::ConstIterator it;
    for (progress = 1, it = files.begin(); it != files.end(); ++progress, ++it) {
@@ -254,94 +255,101 @@ WordMap mergeFiles  (QMap<QString,int> files, KProgressDialog *pdlg) {
       long long weight = 0;
       WordMap::ConstIterator iter;
       for (iter = fileMap.begin(); iter != fileMap.end(); ++iter)
-         weight += iter.data();
-      float factor = 1.0 * it.data() / weight;
-      totalWeight += it.data();
+         weight += iter.value();
+      float factor = 1.0 * it.value() / weight;
+      totalWeight += it.value();
       if (weight > maxWeight)
          maxWeight = weight;
-      
+
       for (iter = fileMap.begin(); iter != fileMap.end(); ++iter)
          if (map.contains(iter.key()))
-            map[iter.key()] += iter.data() * factor;
+            map[iter.key()] += iter.value() * factor;
          else
-            map[iter.key()] = iter.data() * factor;
+            map[iter.key()] = iter.value() * factor;
 
       if (steps != 0 && progress*100/steps > percent) {
          percent = progress*100/steps;
-         pdlg->progressBar()->setProgress(percent);
-         qApp->processEvents (20);
+         pdlg->progressBar()->setValue(percent);
+         qApp->processEvents (QEventLoop::AllEvents, 20);
       }
    }
-   
+
    float factor;
    if (1.0 * maxWeight * totalWeight > 1000000000)
       factor = 1000000000 / totalWeight;
    else
       factor = 1.0 * maxWeight;
-   
+
    WordMap resultMap;
    QMap<QString,float>::ConstIterator iter;
    for (iter = map.begin(); iter != map.end(); ++iter)
-      resultMap[iter.key()] = (int)(factor * iter.data() + 0.5);
-   
+      resultMap[iter.key()] = (int)(factor * iter.value() + 0.5);
+
    return resultMap;
 }
 
 WordMap parseKDEDoc (QString language, KProgressDialog *pdlg) {
-   pdlg->setLabel (i18n("Parsing the KDE documentation..."));
+   pdlg->setLabelText (i18n("Parsing the KDE documentation..."));
    pdlg->show();
-   qApp->processEvents (20);
-   
-   QStringList files = KApplication::kApplication()->dirs()->findAllResources ("html", language + "/*.docbook", true, true);
+   qApp->processEvents (QEventLoop::AllEvents, 20);
+
+   QStringList files = KGlobal::dirs()->findAllResources ("html", language + "/*.docbook",
+                                                          KStandardDirs::Recursive |
+                                                          KStandardDirs::NoDuplicates);
    if ((files.count() == 0) && (language.length() == 5)) {
       language = language.left(2);
-      files = KApplication::kApplication()->dirs()->findAllResources ("html", language + "/*.docbook", true, true);
+      files = KGlobal::dirs()->findAllResources ("html", language + "/*.docbook",
+                                                 KStandardDirs::Recursive |
+                                                 KStandardDirs::NoDuplicates);
    }
 
    return parseFiles (files, QTextStream::UnicodeUTF8, 0, pdlg);
 }
 
 WordMap parseFile (QString filename, QTextStream::Encoding encoding, QTextCodec *codec, KProgressDialog *pdlg) {
-   pdlg->setLabel (i18n("Parsing file..."));
+   pdlg->setLabelText (i18n("Parsing file..."));
    pdlg->show();
-   qApp->processEvents (20);
-   
-   QStringList files = filename;
+   qApp->processEvents (QEventLoop::AllEvents, 20);
+
+   QStringList files;
+   files.append(filename);
 
    return parseFiles (files, encoding, codec, pdlg);
 }
 
 WordMap parseDir (QString directory, QTextStream::Encoding encoding, QTextCodec *codec, KProgressDialog *pdlg) {
-   pdlg->setLabel (i18n("Parsing directory..."));
+   pdlg->setLabelText (i18n("Parsing directory..."));
    pdlg->show();
-   qApp->processEvents (20);
-   
+   qApp->processEvents (QEventLoop::AllEvents, 20);
+
    QStringList directories;
    directories += directory;
    QStringList files;
-   for (QStringList::Iterator it = directories.begin(); it != directories.end(); it = directories.remove(it)) {
-      QDir dir(*it);
-      const QFileInfoList *entries = dir.entryInfoList ("*", QDir::Dirs | QDir::Files | QDir::NoSymLinks | QDir::Readable);
-      if (entries != 0) {
-         QFileInfoListIterator iter (*entries);
-         while ((iter.current()) != 0) {
-            QString name = iter.current()->fileName();
+   int dirNdx = 0;
+   while (dirNdx < directories.count()) {
+      QDir dir(directories.at(dirNdx));
+      const QFileInfoList entries = dir.entryInfoList ("*", QDir::Dirs | QDir::Files | QDir::NoSymLinks | QDir::Readable);
+
+       for (int i = 0; i < entries.size(); ++i) {
+            QFileInfo fileInfo = entries.at(i);
+
+            QString name = fileInfo.fileName();
             if (name != "." && name != "..") {
-               if (iter.current()->isDir())
-                  directories += iter.current()->filePath ();
+               if (fileInfo.isDir())
+                  directories += fileInfo.filePath ();
                else
-                  files += iter.current()->filePath ();
+                  files += fileInfo.filePath ();
             }
-            ++iter;
-         }
-      }
+       }
+       directories.removeAt(dirNdx);
    }
 
    return parseFiles (files, encoding, codec, pdlg);
 }
-
 /***************************************************************************/
 
+#include <QList>
+
 /* Structures used for storing *.aff files (part of OpenOffice.org dictionaries)
  */
 struct AffEntry {
@@ -350,7 +358,8 @@ struct AffEntry {
    QString add;
    QStringList condition;
 };
-typedef QValueList<AffEntry> AffList;
+
+typedef QList<AffEntry> AffList;
 typedef QMap<QChar,AffList>  AffMap;
 
 /** Loads an *.aff file (part of OpenOffice.org dictionaries)
@@ -359,11 +368,11 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes) {
    bool cross = false;
 
    QFile afile(filename);
-   if (afile.open(IO_ReadOnly)) {
+   if (afile.open(QIODevice::ReadOnly)) {
       QTextStream stream(&afile);
       while (!stream.atEnd()) {
          QString s = stream.readLine();
-         QStringList fields = QStringList::split(QRegExp("\\s"), s);
+         QStringList fields = s.split( QRegExp("\\s"));
 
          if (fields.count() == 4) {
             cross = (fields[2] == "Y");
@@ -380,7 +389,7 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes) {
 
                if (fields[4] != ".") {
                   QString condition = fields[4];
-                  for (uint idx = 0; idx < condition.length(); ++idx) {
+                  for (int idx = 0; idx < condition.length(); ++idx) {
                      if (condition[idx] == '[') {
                         QString code;
                         for (++idx; (idx < condition.length()) && condition[idx] != ']'; ++idx)
@@ -391,7 +400,7 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes) {
                         e.condition << QString(condition[idx]);
                   }
                }
-               
+
                if (s.startsWith("PFX")) {
                   AffList list;
                   if (prefixes.contains (fields[1][0]))
@@ -425,7 +434,7 @@ inline bool checkCondition (const QString &word, const QStringList &condition) {
 
    if (word.length() < condition.count())
       return false;
-   
+
    QStringList::ConstIterator it;
    int idx;
    for (it = condition.begin(), idx = word.length()-condition.count();
@@ -444,7 +453,7 @@ inline bool checkCondition (const QString &word, const QStringList &condition) {
  * @param cross true if the word has a prefix
  */
 inline void checkWord(const QString &word, const QString &modifiers, bool cross, const WordMap &map, WordMap &checkedMap, const AffMap &suffixes) {
-   for (uint i = 0; i < modifiers.length(); i++) {
+   for (int i = 0; i < modifiers.length(); i++) {
       if (suffixes.contains(modifiers[i])) {
          AffList sList = suffixes[modifiers[i]];
 
@@ -472,7 +481,7 @@ void checkWord (const QString &word, const QString &modifiers, const WordMap &ma
 
    checkWord(word, modifiers, true, map, checkedMap, suffixes);
 
-   for (uint i = 0; i < modifiers.length(); i++) {
+   for (int i = 0; i < modifiers.length(); i++) {
       if (prefixes.contains(modifiers[i])) {
          AffList pList = prefixes[modifiers[i]];
 
@@ -501,18 +510,18 @@ WordMap spellCheck  (WordMap map, QString dictionary, KProgressDialog *pdlg) {
       pdlg->showCancelButton (false);
       pdlg->setAutoReset(false);
       pdlg->setAutoClose(false);
-      pdlg->setLabel (i18n("Performing spell check..."));
-      pdlg->progressBar()->setTotalSteps(100);
-      pdlg->progressBar()->setProgress(0);
-      qApp->processEvents (20);
+      pdlg->setLabelText (i18n("Performing spell check..."));
+      pdlg->progressBar()->setMaximum(100);
+      pdlg->progressBar()->setValue(0);
+      qApp->processEvents (QEventLoop::AllEvents, 20);
       int progress = 0;
       int steps = 0;
       int percent = 0;
 
       QFile dfile(dictionary);
-      if (dfile.open(IO_ReadOnly)) {
+      if (dfile.open(QIODevice::ReadOnly)) {
          QTextStream stream(&dfile);
-         
+
          if (!stream.atEnd()) {
             QString s = stream.readLine(); // Number of words
             steps = s.toInt();
@@ -521,21 +530,21 @@ WordMap spellCheck  (WordMap map, QString dictionary, KProgressDialog *pdlg) {
          while (!stream.atEnd()) {
             QString s = stream.readLine();
             if (s.contains("/")) {
-               QString word = s.left(s.find("/")).lower();
-               QString modifiers = s.right(s.length() - s.find("/"));
-            
+               QString word = s.left(s.indexOf("/")).toLower();
+               QString modifiers = s.right(s.length() - s.indexOf("/"));
+
                checkWord(word, modifiers, map, checkedMap, prefixes, suffixes);
             }
             else {
-               if (!s.isEmpty() && !s.isNull() && map.contains(s.lower()))
-                  checkedMap[s.lower()] = map[s.lower()];
+               if (!s.isEmpty() && !s.isNull() && map.contains(s.toLower()))
+                  checkedMap[s.toLower()] = map[s.toLower()];
             }
-            
+
             progress++;
             if (steps != 0 && progress*100/steps > percent) {
                percent = progress*100/steps;
-               pdlg->progressBar()->setProgress(percent);
-               qApp->processEvents (20);
+               pdlg->progressBar()->setValue(percent);
+               qApp->processEvents (QEventLoop::AllEvents, 20);
             }
          }
       }
