@@ -22,85 +22,82 @@
  ******************************************************************************/
 
 // Qt includes.
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qstring.h>
-#include <qhbox.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qdom.h>
-#include <qfile.h>
-#include <qradiobutton.h>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtXml/QDomDocument>
+#include <QtGui/QRadioButton>
+#include <QtCore/QTextStream>
+#include <QtGui/QTableWidget>
+#include <QtGui/QHeaderView>
 
 // KDE includes.
 #include <kglobal.h>
 #include <klocale.h>
-#include <klistview.h>
 #include <klineedit.h>
 #include <kdialog.h>
-#include <kdialogbase.h>
 #include <kpushbutton.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <kregexpeditorinterface.h>
-#include <ktrader.h>
 #include <kparts/componentfactory.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
+#include <khbox.h>
+#include <kservicetypetrader.h>
 
 // KTTS includes.
+#include "selectlanguagedlg.h"
 #include "filterconf.h"
 
 // StringReplacer includes.
 #include "stringreplacerconf.h"
 #include "stringreplacerconf.moc"
-#include "editreplacementwidget.h"
 
 /**
 * Constructor 
 */
-StringReplacerConf::StringReplacerConf( QWidget *parent, const char *name, const QStringList& /*args*/) :
-    KttsFilterConf(parent, name),
+StringReplacerConf::StringReplacerConf( QWidget *parent, const QStringList& args ) :
+    KttsFilterConf(parent),
     m_editDlg(0),
     m_editWidget(0)
 {
-    // kdDebug() << "StringReplacerConf::StringReplacerConf: Running" << endl;
+    Q_UNUSED(args);
+    // kDebug() << "StringReplacerConf::StringReplacerConf: Running";
 
     // Create configuration widget.
-    QVBoxLayout *layout = new QVBoxLayout(this, KDialog::marginHint(),
-        KDialog::spacingHint(), "StringReplacerConfigWidgetLayout");
-    layout->setAlignment (Qt::AlignTop);
-    m_widget = new StringReplacerConfWidget(this, "StringReplacerConfigWidget");
-    layout->addWidget(m_widget);
-    m_widget->substLView->setSortColumn(-1);
+    setupUi(this);
 
-    connect(m_widget->nameLineEdit, SIGNAL(textChanged(const QString&)),
+    substLView->setSortingEnabled(false);
+    substLView->verticalHeader()->hide();
+    substLView->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+
+    connect(nameLineEdit, SIGNAL(textChanged(const QString&)),
         this, SLOT(configChanged()));
-    connect(m_widget->languageBrowseButton, SIGNAL(clicked()),
+    connect(languageBrowseButton, SIGNAL(clicked()),
         this, SLOT(slotLanguageBrowseButton_clicked()));
-    connect(m_widget->addButton, SIGNAL(clicked()),
+    connect(addButton, SIGNAL(clicked()),
         this, SLOT(slotAddButton_clicked()));
-    connect(m_widget->upButton, SIGNAL(clicked()),
+    connect(upButton, SIGNAL(clicked()),
         this, SLOT(slotUpButton_clicked()));
-    connect(m_widget->downButton, SIGNAL(clicked()),
+    connect(downButton, SIGNAL(clicked()),
         this, SLOT(slotDownButton_clicked()));
-    connect(m_widget->editButton, SIGNAL(clicked()),
+    connect(editButton, SIGNAL(clicked()),
         this, SLOT(slotEditButton_clicked()));
-    connect(m_widget->removeButton, SIGNAL(clicked()),
+    connect(removeButton, SIGNAL(clicked()),
         this, SLOT(slotRemoveButton_clicked()));
-    connect(m_widget->loadButton, SIGNAL(clicked()),
+    connect(loadButton, SIGNAL(clicked()),
         this, SLOT(slotLoadButton_clicked()));
-    connect(m_widget->saveButton, SIGNAL(clicked()),
+    connect(saveButton, SIGNAL(clicked()),
         this, SLOT(slotSaveButton_clicked()));
-    connect(m_widget->clearButton, SIGNAL(clicked()),
+    connect(clearButton, SIGNAL(clicked()),
         this, SLOT(slotClearButton_clicked()));
-    connect(m_widget->substLView, SIGNAL(selectionChanged()),
+    connect(substLView, SIGNAL(currentItemChanged(QTableWidgetItem *, QTableWidgetItem *)),
         this, SLOT(enableDisableButtons()));
-    connect(m_widget->appIdLineEdit, SIGNAL(textChanged(const QString&)),
+    connect(appIdLineEdit, SIGNAL(textChanged(const QString&)),
         this, SLOT(configChanged()));
 
     // Determine if kdeutils Regular Expression Editor is installed.
-    m_reEditorInstalled = !KTrader::self()->query("KRegExpEditor/KRegExpEditor").isEmpty();
+    m_reEditorInstalled = !KServiceTypeTrader::self()->query("KRegExpEditor/KRegExpEditor").isEmpty();
 
     // Set up defaults.
     defaults();
@@ -110,7 +107,7 @@ StringReplacerConf::StringReplacerConf( QWidget *parent, const char *name, const
 * Destructor.
 */
 StringReplacerConf::~StringReplacerConf(){
-    // kdDebug() << "StringReplacerConf::~StringReplacerConf: Running" << endl;
+    // kDebug() << "StringReplacerConf::~StringReplacerConf: Running";
 }
 
 /**
@@ -126,16 +123,16 @@ StringReplacerConf::~StringReplacerConf(){
 * @param configGroup Call config->setGroup with this argument before
 *                    loading your configuration.
 */
-void StringReplacerConf::load(KConfig* config, const QString& configGroup){
-    // kdDebug() << "StringReplacerConf::load: Running" << endl;
+void StringReplacerConf::load(KConfig* c, const QString& configGroup){
+    // kDebug() << "StringReplacerConf::load: Running";
     // See if this filter previously save its word list.
-    config->setGroup( configGroup );
-    QString wordsFilename = config->readEntry( "WordListFile" );
+    KConfigGroup config( c, configGroup );
+    QString wordsFilename = config.readEntry( "WordListFile" );
     if ( !wordsFilename.isEmpty() )
     {
         QString errMsg = loadFromFile( wordsFilename, true );
         if ( !errMsg.isEmpty() )
-            kdDebug() << "StringReplacerConf::load: " << errMsg << endl;
+            kDebug() << "StringReplacerConf::load: " << errMsg;
         enableDisableButtons();
     }
 }
@@ -145,7 +142,7 @@ QString StringReplacerConf::loadFromFile( const QString& filename, bool clear)
 {
     // Open existing word list.
     QFile file( filename );
-    if ( !file.open( IO_ReadOnly ) )
+    if ( !file.open( QIODevice::ReadOnly ) )
     {
         return i18n("Unable to open file.") + filename;
     }
@@ -155,77 +152,78 @@ QString StringReplacerConf::loadFromFile( const QString& filename, bool clear)
         file.close();
         return i18n("File not in proper XML format.");
     }
-    // kdDebug() << "StringReplacerConf::load: document successfully parsed." << endl;
+    // kDebug() << "StringReplacerConf::load: document successfully parsed.";
     file.close();
 
     // Clear list view.
-    if ( clear ) m_widget->substLView->clear();
+    if ( clear ) substLView->setRowCount(0);
 
     // Name setting.
     QDomNodeList nameList = doc.elementsByTagName( "name" );
     QDomNode nameNode = nameList.item( 0 );
-    m_widget->nameLineEdit->setText( nameNode.toElement().text() );
-    // kdDebug() << "StringReplacerConf::load: name = " << nameNode.toElement().text() << endl;
+    nameLineEdit->setText( nameNode.toElement().text() );
+    // kDebug() << "StringReplacerConf::load: name = " << nameNode.toElement().text();
 
     // Language Codes setting.  List may be single element of comma-separated values,
     // or multiple elements.
     QString languageCodes;
     QDomNodeList languageList = doc.elementsByTagName( "language-code" );
-    for ( uint ndx=0; ndx < languageList.count(); ++ndx )
+    for ( int ndx=0; ndx < languageList.count(); ++ndx )
     {
         QDomNode languageNode = languageList.item( ndx );
-        if (!languageCodes.isEmpty()) languageCodes += ",";
+        if (!languageCodes.isEmpty()) languageCodes += ',';
         languageCodes += languageNode.toElement().text();
     }
     if ( clear )
-        m_languageCodeList = QStringList::split(',', languageCodes, false);
+        m_languageCodeList = languageCodes.split(',', QString::SkipEmptyParts);
     else
-        m_languageCodeList += QStringList::split(',', languageCodes, false);
+        m_languageCodeList += languageCodes.split(',', QString::SkipEmptyParts);
     QString language;
     m_languageCodeList.sort();
     // Eliminate dups.
-    for ( int ndx = m_languageCodeList.count() - 2; ndx >= 0; --ndx )
     {
-        if ( m_languageCodeList[ndx] == m_languageCodeList[ndx+1] )
-            m_languageCodeList.remove(m_languageCodeList.at(ndx+1));
+        int ndx = m_languageCodeList.count() - 2;
+        while ( ndx >= 0 ) {
+            if ( m_languageCodeList[ndx] == m_languageCodeList[ndx+1] )
+                m_languageCodeList.removeAt(ndx+1);
+            ndx--;
+        }
     }
-    for ( uint ndx=0; ndx < m_languageCodeList.count(); ++ndx )
+    for ( int ndx=0; ndx < m_languageCodeList.count(); ++ndx )
     {
-        if (!language.isEmpty()) language += ",";
-        language += KGlobal::locale()->twoAlphaToLanguageName(m_languageCodeList[ndx]);
+        if (!language.isEmpty()) language += ',';
+        language += KGlobal::locale()->languageCodeToName(m_languageCodeList[ndx]);
     }
-    m_widget->languageLineEdit->setText(language);
+    languageLineEdit->setText(language);
 
     // AppId.  Apply this filter only if DCOP appId of application that queued
     // the text contains this string.  List may be single element of comma-separated values,
     // or multiple elements.
     QDomNodeList appIdList = doc.elementsByTagName( "appid" );
     QString appIds;
-    for ( uint ndx=0; ndx < appIdList.count(); ++ndx )
+    for ( int ndx=0; ndx < appIdList.count(); ++ndx )
     {
         QDomNode appIdNode = appIdList.item( ndx );
-        if (!appIds.isEmpty()) appIds += ",";
+        if (!appIds.isEmpty()) appIds += ',';
         appIds += appIdNode.toElement().text();
     }
-    if ( !clear ) appIds = m_widget->appIdLineEdit->text() + appIds;
-    m_widget->appIdLineEdit->setText( appIds );
+    if ( !clear ) appIds = appIdLineEdit->text() + appIds;
+    appIdLineEdit->setText( appIds );
 
     // Word list.
-    QListViewItem* item = 0;
-    if ( !clear ) item = m_widget->substLView->lastChild();
-    QDomNodeList wordList = doc.elementsByTagName("word");
+    QDomNodeList wordList = doc.elementsByTagName( "word" );
     const int wordListCount = wordList.count();
-    for (int wordIndex = 0; wordIndex < wordListCount; ++wordIndex)
+    for ( int wordIndex = 0; wordIndex < wordListCount; ++wordIndex )
     {
-        // kdDebug() << "StringReplacerConf::load: start parsing of word " << wordIndex << endl;
+        // kDebug() << "StringReplacerConf::load: start parsing of word " << wordIndex;
         QDomNode wordNode = wordList.item(wordIndex);
         QDomNodeList propList = wordNode.childNodes();
         QString wordType;
-        QString matchCase = "No"; // Default for old (v<=3.5.3) config files with no <case/>.
+        QString matchCase = "No";
         QString match;
         QString subst;
         const int propListCount = propList.count();
-        for (int propIndex = 0; propIndex < propListCount; ++propIndex)
+        for ( int propIndex = 0; propIndex < propListCount; ++propIndex )
         {
             QDomNode propNode = propList.item(propIndex);
             QDomElement prop = propNode.toElement();
@@ -235,16 +233,18 @@ QString StringReplacerConf::loadFromFile( const QString& filename, bool clear)
             if (prop.tagName() == "subst") subst = prop.text();
         }
         QString wordTypeStr = 
-            (wordType=="RegExp"?i18n("Abbreviation for 'Regular Expression'", "RegExp"):i18n("Word"));
+            (wordType=="RegExp"?i18nc("Abbreviation for 'Regular Expression'", "RegExp"):i18n("Word"));
+        int tableRow = substLView->rowCount();
         QString matchCaseStr = 
             (matchCase=="Yes"?i18n("Yes"):i18n("No"));  
-        if (!item)
-            item = new KListViewItem(m_widget->substLView, wordTypeStr, matchCaseStr, match, subst);
-        else
-            item = new KListViewItem(m_widget->substLView, item, wordTypeStr, matchCaseStr, match, subst);
+        substLView->setRowCount( tableRow + 1 );
+        substLView->setItem( tableRow, 0, new QTableWidgetItem( wordTypeStr ) );
+        substLView->setItem( tableRow, 1, new QTableWidgetItem( matchCaseStr ) );
+        substLView->setItem( tableRow, 2, new QTableWidgetItem( match ) );
+        substLView->setItem( tableRow, 3, new QTableWidgetItem( subst ) );
     }
 
-    return QString::null;
+    return QString();
 }
 
 /**
@@ -257,33 +257,33 @@ QString StringReplacerConf::loadFromFile( const QString& filename, bool clear)
 * @param configGroup Call config->setGroup with this argument before
 *                    saving your configuration.
 */
-void StringReplacerConf::save(KConfig* config, const QString& configGroup){
-    // kdDebug() << "StringReplacerConf::save: Running" << endl;
+void StringReplacerConf::save(KConfig* c, const QString& configGroup){
+    // kDebug() << "StringReplacerConf::save: Running";
     QString wordsFilename =
         KGlobal::dirs()->saveLocation( "data" ,"kttsd/stringreplacer/", true );
     if ( wordsFilename.isEmpty() )
     {
-        kdDebug() << "StringReplacerConf::save: no save location" << endl;
+        kDebug() << "StringReplacerConf::save: no save location";
         return;
     }
     wordsFilename += configGroup;
     QString errMsg = saveToFile( wordsFilename );
     if ( errMsg.isEmpty() )
     {
-        config->setGroup( configGroup );
-        config->writeEntry( "WordListFile", realFilePath(wordsFilename) );
+        KConfigGroup config( c, configGroup );
+        config.writeEntry( "WordListFile", realFilePath(wordsFilename) );
     }
     else
-        kdDebug() << "StringReplacerConf::save: " << errMsg << endl;
+        kDebug() << "StringReplacerConf::save: " << errMsg;
 }
 
 // Saves word list and settings to a file.
 QString StringReplacerConf::saveToFile(const QString& filename)
 {
-    // kdDebug() << "StringReplacerConf::saveToFile: saving to file " << wordsFilename << endl;
+    // kDebug() << "StringReplacerConf::saveToFile: saving to file " << wordsFilename;
 
     QFile file( filename );
-    if ( !file.open( IO_WriteOnly ) )
+    if ( !file.open( QIODevice::WriteOnly ) )
         return i18n("Unable to open file ") + filename;
 
     // QDomDocument doc( "http://www.kde.org/share/apps/kttsd/stringreplacer/wordlist.dtd []" );
@@ -295,11 +295,11 @@ QString StringReplacerConf::saveToFile(const QString& filename)
     // Name.
     QDomElement name = doc.createElement( "name" );
     root.appendChild( name );
-    QDomText t = doc.createTextNode( m_widget->nameLineEdit->text() );
+    QDomText t = doc.createTextNode( nameLineEdit->text() );
     name.appendChild( t );
 
     // Language code.
-    for ( uint ndx=0; ndx < m_languageCodeList.count(); ++ndx )
+    for ( int ndx=0; ndx < m_languageCodeList.count(); ++ndx )
     {
         QDomElement languageCode = doc.createElement( "language-code" );
         root.appendChild( languageCode );
@@ -308,11 +308,11 @@ QString StringReplacerConf::saveToFile(const QString& filename)
     }
 
     // Application ID
-    QString appId = m_widget->appIdLineEdit->text().replace(" ", "");
+    QString appId = appIdLineEdit->text().replace(" ", "");
     if ( !appId.isEmpty() )
     {
-        QStringList appIdList = QStringList::split(",", appId);
-        for ( uint ndx=0; ndx < appIdList.count(); ++ndx )
+        QStringList appIdList = appId.split( ",", QString::SkipEmptyParts );
+        for ( int ndx=0; ndx < appIdList.count(); ++ndx )
         {
             QDomElement appIdElem = doc.createElement( "appid" );
             root.appendChild( appIdElem );
@@ -322,44 +322,42 @@ QString StringReplacerConf::saveToFile(const QString& filename)
     }
 
     // Words.
-    QListView* lView = m_widget->substLView;
-    QListViewItem* item = lView->firstChild();
-    while (item)
+    for ( int row = 0; row < substLView->rowCount(); ++row )
     {
         QDomElement wordTag = doc.createElement( "word" );
         root.appendChild( wordTag );
         QDomElement propTag = doc.createElement( "type" );
         wordTag.appendChild( propTag);
-        QDomText t = doc.createTextNode( item->text(0)==i18n("Word")?"Word":"RegExp" );
+        QDomText t = doc.createTextNode( 
+            substLView->item(row, 0)->text()==i18n("Word")?"Word":"RegExp" );
         propTag.appendChild( t );
 
         propTag = doc.createElement( "case" );
         wordTag.appendChild( propTag);
-        t = doc.createTextNode( item->text(1)==i18n("Yes")?"Yes":"No" );
+        t = doc.createTextNode(
+            substLView->item(row, 2)->text()==i18n("Yes")?"Yes":"No" );
         propTag.appendChild( t );      
 
         propTag = doc.createElement( "match" );
         wordTag.appendChild( propTag);
-        t = doc.createCDATASection( item->text(2) );
+        t = doc.createCDATASection( substLView->item(row, 2)->text() );
         propTag.appendChild( t );
 
         propTag = doc.createElement( "subst" );
         wordTag.appendChild( propTag);
-        t = doc.createCDATASection( item->text(3) );
+        t = doc.createCDATASection( substLView->item(row, 3)->text() );
         propTag.appendChild( t );
-
-        item = item->nextSibling();
     }
 
     // Write it all out.
     QTextStream ts( &file );
-    ts.setEncoding( QTextStream::UnicodeUTF8 );
+    ts.setCodec( "UTF-8" );
     ts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
     ts << doc.toString();
-    // kdDebug() << "StringReplacerConf::saveToFile: writing out " << doc.toString() << endl;
+    // kDebug() << "StringReplacerConf::saveToFile: writing out " << doc.toString();
     file.close();
 
-    return QString::null;
+    return QString();
 }
 
 /** 
@@ -370,17 +368,17 @@ QString StringReplacerConf::saveToFile(const QString& filename)
 * be applied to the on-screen widgets; not to the config file.
 */
 void StringReplacerConf::defaults(){
-    // kdDebug() << "StringReplacerConf::defaults: Running" << endl;
+    // kDebug() << "StringReplacerConf::defaults: Running";
     // Default language is none.
     m_languageCodeList.clear();
-    m_widget->languageLineEdit->setText( "" );
+    languageLineEdit->setText( "" );
     // Default name.
-    m_widget->nameLineEdit->setText( i18n("String Replacer") );
-    m_widget->substLView->clear();
+    nameLineEdit->setText( i18n("String Replacer") );
+    substLView->setRowCount(0);
     // Default App ID is blank.
-    m_widget->appIdLineEdit->setText( "" );
+    appIdLineEdit->setText( "" );
     enableDisableButtons();
-    // kdDebug() << "StringReplacerConf::defaults: Exiting" << endl;
+    // kDebug() << "StringReplacerConf::defaults: Exiting";
 }
 
 /**
@@ -400,91 +398,55 @@ bool StringReplacerConf::supportsMultiInstance() { return true; }
  */
 QString StringReplacerConf::userPlugInName()
 {
-    if ( m_widget->substLView->childCount() == 0 ) return QString::null;
-    QString instName = m_widget->nameLineEdit->text();
+    if ( substLView->rowCount() == 0 ) return QString();
+    QString instName = nameLineEdit->text();
     if ( instName.isEmpty() )
     {
         QString language;
         if (m_languageCodeList.count() == 1)
-            language = KGlobal::locale()->twoAlphaToLanguageName(m_languageCodeList[0]);
+            language = KGlobal::locale()->languageCodeToName(m_languageCodeList[0]);
         if (m_languageCodeList.count() > 1)
             language = i18n("Multiple Languages");
         if (!language.isEmpty())
-            instName = i18n("String Replacer") + " (" + language + ")";
+            instName = i18n("String Replacer") + " (" + language + ')';
     }
     return instName;
 }
 
+// Converts a Substitution Type to displayable string.
+QString StringReplacerConf::substitutionTypeToString(const int substitutionType)
+{
+    switch (substitutionType)
+    {
+        case stWord:        return i18n("Word");
+        case stRegExp:      return i18nc("Abbreviation for 'Regular Expresion'", "RegExp");
+    }
+    return i18n("Error");
+}
+
 void StringReplacerConf::slotLanguageBrowseButton_clicked()
 {
-    // Create a  QHBox to host KListView.
-    QHBox* hBox = new QHBox(m_widget, "SelectLanguage_hbox");
-    // Create a KListView and fill with all known languages.
-    KListView* langLView = new KListView(hBox, "SelectLanguage_lview");
-    langLView->addColumn(i18n("Language"));
-    langLView->addColumn(i18n("Code"));
-    langLView->setSelectionMode(QListView::Extended);
-    QStringList allLocales = KGlobal::locale()->allLanguagesTwoAlpha();
-    QString locale;
-    QString languageCode;
-    QString countryCode;
-    QString charSet;
-    QString language;
-    // Blank line so user can select no language.
-    QListViewItem* item = new KListViewItem(langLView, "", "");
-    if (m_languageCodeList.isEmpty()) item->setSelected(true);
-    const int allLocalesCount = allLocales.count();
-    for (int ndx=0; ndx < allLocalesCount; ++ndx)
-    {
-        locale = allLocales[ndx];
-        KGlobal::locale()->splitLocale(locale, languageCode, countryCode, charSet);
-        language = KGlobal::locale()->twoAlphaToLanguageName(languageCode);
-        if (!countryCode.isEmpty()) language +=
-            " (" + KGlobal::locale()->twoAlphaToCountryName(countryCode)+")";
-        item = new KListViewItem(langLView, language, locale);
-        if (m_languageCodeList.contains(locale)) item->setSelected(true);
-    }
-    // Sort by language.
-    langLView->setSorting(0);
-    langLView->sort();
-    // Display the box in a dialog.
-    KDialogBase* dlg = new KDialogBase(
-        KDialogBase::Swallow,
+    SelectLanguageDlg* dlg = new SelectLanguageDlg(
+        this,
         i18n("Select Languages"),
-        KDialogBase::Help|KDialogBase::Ok|KDialogBase::Cancel,
-        KDialogBase::Cancel,
-        m_widget,
-        "SelectLanguage_dlg",
-        true,
-        true);
-    dlg->setMainWidget(hBox);
-    dlg->setHelp("", "kttsd");
-    dlg->setInitialSize(QSize(300, 500), false);
+        QStringList(m_languageCodeList),
+        SelectLanguageDlg::MultipleSelect,
+        SelectLanguageDlg::BlankAllowed);
     int dlgResult = dlg->exec();
-    languageCode = QString::null;
     if (dlgResult == QDialog::Accepted)
-    {
-        m_languageCodeList.clear();
-        QListViewItem* item = langLView->firstChild();
-        while (item)
-        {
-            if (item->isSelected()) m_languageCodeList += item->text(1);
-            item = item->nextSibling();
-        }
-    }
+        m_languageCodeList = dlg->selectedLanguageCodes();
     delete dlg;
-    // TODO: Also delete KListView and QHBox?
     if (dlgResult != QDialog::Accepted) return;
-    language = "";
-    for ( uint ndx=0; ndx < m_languageCodeList.count(); ++ndx)
+    QString language("");
+    for ( int ndx=0; ndx < m_languageCodeList.count(); ++ndx)
     {
-        if (!language.isEmpty()) language += ",";
-        language += KGlobal::locale()->twoAlphaToLanguageName(m_languageCodeList[ndx]);
+        if (!language.isEmpty()) language += ',';
+        language += KGlobal::locale()->languageCodeToName(m_languageCodeList[ndx]);
     }
-    QString s1 = m_widget->languageLineEdit->text();
-    m_widget->languageLineEdit->setText(language);
+    QString s1 = languageLineEdit->text();
+    languageLineEdit->setText(language);
     // Replace language in the user's filter name.
-    QString s2 = m_widget->nameLineEdit->text();
+    QString s2 = nameLineEdit->text();
     if (m_languageCodeList.count() > 1) language = i18n("Multiple Languages");
     if ( !s1.isEmpty() )
     {
@@ -492,52 +454,95 @@ void StringReplacerConf::slotLanguageBrowseButton_clicked()
         s2.replace( i18n("Multiple Languages"), language );
     }
     s2.replace(" ()", "");
-    if ( !s2.contains("(") && !language.isEmpty() ) s2 += " (" + language + ")";
-    m_widget->nameLineEdit->setText(s2);
+    if ( !s2.contains("(") && !language.isEmpty() ) s2 += " (" + language + ')';
+    nameLineEdit->setText(s2);
     configChanged();
 }
 
 void StringReplacerConf::enableDisableButtons()
 {
-    bool enableBtn = (m_widget->substLView->selectedItem() != 0);
+    int row = substLView->currentRow();
+    bool enableBtn = (row >= 0 && row < substLView->rowCount());
     if (enableBtn)
     {
-        m_widget->upButton->setEnabled(
-            m_widget->substLView->selectedItem()->itemAbove() != 0);
-        m_widget->downButton->setEnabled(
-            m_widget->substLView->selectedItem()->itemBelow() != 0);
+        upButton->setEnabled(row > 0);
+        downButton->setEnabled(row < (substLView->rowCount() - 1));
     } else {
-        m_widget->upButton->setEnabled(false);
-        m_widget->downButton->setEnabled(false);
+        upButton->setEnabled(false);
+        downButton->setEnabled(false);
     }
-    m_widget->editButton->setEnabled(enableBtn);
-    m_widget->removeButton->setEnabled(enableBtn);
-    m_widget->clearButton->setEnabled(m_widget->substLView->firstChild());
-    m_widget->saveButton->setEnabled(m_widget->substLView->firstChild());
+    editButton->setEnabled(enableBtn);
+    removeButton->setEnabled(enableBtn);
+    clearButton->setEnabled(substLView->rowCount() > 0);
+    saveButton->setEnabled(substLView->rowCount() > 0);
 }
 
 void StringReplacerConf::slotUpButton_clicked()
 {
-    QListViewItem* item = m_widget->substLView->selectedItem();
-    if (!item) return;
-    QListViewItem* prevItem = item->itemAbove();
-    if (!prevItem) return;
-    prevItem->moveItem(item);
-    m_widget->substLView->setSelected(item, true);
-    m_widget->substLView->ensureItemVisible(item);
+    int row = substLView->currentRow();
+    if (row < 1 || row >= substLView->rowCount()) return;
+
+    QTableWidgetItem *itemAbove = substLView->item(row - 1, 0);
+    QTableWidgetItem *item = substLView->item(row, 0);
+    QString t = itemAbove->text();
+    itemAbove->setText(item->text());
+    item->setText(t);
+
+    itemAbove = substLView->item(row - 1, 1);
+    item = substLView->item(row, 1);
+    t = itemAbove->text();
+    itemAbove->setText(item->text());
+    item->setText(t);
+
+    itemAbove = substLView->item(row - 1, 2);
+    item = substLView->item(row, 2);
+    t = itemAbove->text();
+    itemAbove->setText(item->text());
+    item->setText(t);
+
+    itemAbove = substLView->item(row - 1, 3);
+    item = substLView->item(row, 3);
+    t = itemAbove->text();
+    itemAbove->setText(item->text());
+    item->setText(t);
+
+    substLView->setCurrentItem(substLView->item(row - 1, substLView->currentColumn()));
+    // TODO: Is this needed? substLView->scrollTo(substLView->indexFromItem(itemAbove));
     enableDisableButtons();
     configChanged();
 }
 
 void StringReplacerConf::slotDownButton_clicked()
 {
-    QListViewItem* item = m_widget->substLView->selectedItem();
-    if (!item) return;
-    QListViewItem* nextItem = item->itemBelow();
-    if (!nextItem) return;
-    item->moveItem(nextItem);
-    m_widget->substLView->setSelected(item, true);
-    m_widget->substLView->ensureItemVisible(item);
+    int row = substLView->currentRow();
+    if (row < 0 || row >= substLView->rowCount() - 1) return;
+
+    QTableWidgetItem *itemBelow = substLView->item(row + 1, 0);
+    QTableWidgetItem *item = substLView->item(row, 0);
+    QString t = itemBelow->text();
+    itemBelow->setText(item->text());
+    item->setText(t);
+
+    itemBelow = substLView->item(row + 1, 1);
+    item = substLView->item(row, 1);
+    t = itemBelow->text();
+    itemBelow->setText(item->text());
+    item->setText(t);
+
+    itemBelow = substLView->item(row + 1, 2);
+    item = substLView->item(row, 2);
+    t = itemBelow->text();
+    itemBelow->setText(item->text());
+    item->setText(t);
+
+    itemBelow = substLView->item(row + 1, 3);
+    item = substLView->item(row, 3);
+    t = itemBelow->text();
+    itemBelow->setText(item->text());
+    item->setText(t);
+
+    substLView->setCurrentItem(substLView->item(row + 1, substLView->currentColumn()));
+    // TODO: Is this needed? substLView->scrollTo(substLView->indexFromItem(itemBelow));
     enableDisableButtons();
     configChanged();
 }
@@ -555,30 +560,28 @@ void StringReplacerConf::slotEditButton_clicked()
 // Displays the add/edit string replacement dialog.
 void StringReplacerConf::addOrEditSubstitution(bool isAdd)
 {
-    QListViewItem* item = 0;
+    int row;
     if (isAdd)
-        item = m_widget->substLView->lastChild();
+        row = substLView->rowCount() - 1;
     else
-    {
-        item = m_widget->substLView->selectedItem();
-        if (!item) return;
-    }
-    // Create a QHBox to host widget.
-    QHBox* hBox = new QHBox(m_widget, "AddOrEditSubstitution_hbox" );
+        row = substLView->currentRow();
     // Create widget.
-    m_editWidget = new EditReplacementWidget( hBox, "AddOrEditSubstitution_widget" );
+    QWidget *w = new QWidget();
+    m_editWidget = new Ui::EditReplacementWidget();
+    m_editWidget->setupUi( w );
     // Set controls if editing existing.
     m_editWidget->matchButton->setEnabled( false );
     if (!isAdd)
     {
-        if ( item->text(0) == i18n("Abbreviation for 'Regular Expression'", "RegExp") )
+        if ( substLView->item(row, 0)->text() != i18n("Word") )
         {
             m_editWidget->regexpRadioButton->setChecked( true );
             m_editWidget->matchButton->setEnabled( m_reEditorInstalled );
         }
-        m_editWidget->caseCheckBox->setChecked( (item->text(1))==i18n("Yes") );
-        m_editWidget->matchLineEdit->setText( item->text(2) );
-        m_editWidget->substLineEdit->setText( item->text(3) );
+        if ( substLView->item(row, 1)->text() == i18n("Yes") )
+            m_editWidget->matchCaseCheckBox->setChecked( true );
+        m_editWidget->matchLineEdit->setText( substLView->item(row, 2)->text() );
+        m_editWidget->substLineEdit->setText( substLView->item(row, 3)->text() );
     }
     // The match box may not be blank.
     connect( m_editWidget->matchLineEdit, SIGNAL(textChanged(const QString&)),
@@ -590,49 +593,41 @@ void StringReplacerConf::addOrEditSubstitution(bool isAdd)
     connect( m_editWidget->matchButton, SIGNAL(clicked()),
          this, SLOT(slotMatchButton_clicked()) );
     // Display the box in a dialog.
-    m_editDlg = new KDialogBase(
-        KDialogBase::Swallow,
-        i18n("Edit String Replacement"),
-        KDialogBase::Help|KDialogBase::Ok|KDialogBase::Cancel,
-        KDialogBase::Cancel,
-        m_widget,
-        "AddOrEditSubstitution_dlg",
-        true,
-        true);
+    m_editDlg = new KDialog(this);
+    m_editDlg->setCaption(i18n("Edit String Replacement"));
+    m_editDlg->setButtons(KDialog::Help|KDialog::Ok|KDialog::Cancel);
+    // TODO: KDialog bug workaround.  Remove when no longer needed.
+    m_editDlg->setDefaultButton(KDialog::Cancel);
     // Disable OK button if match field blank.
-    m_editDlg->setMainWidget( hBox );
+    m_editDlg->setMainWidget( w );
     m_editDlg->setHelp( "", "kttsd" );
-    m_editDlg->enableButton( KDialogBase::Ok, !m_editWidget->matchLineEdit->text().isEmpty() );
+    m_editDlg->enableButton( KDialog::Ok, !m_editWidget->matchLineEdit->text().isEmpty() );
     int dlgResult = m_editDlg->exec();
     QString substType = i18n( "Word" );
-    if ( m_editWidget->regexpRadioButton->isChecked() )
-    	substType = i18n("Abbreviation for 'Regular Expression'", "RegExp");
-    QString matchCase = i18n("No");
-    if ( m_editWidget->caseCheckBox->isChecked() ) matchCase = i18n("Yes");
+    if ( m_editWidget->regexpRadioButton->isChecked() ) 
+        substType = i18nc("Abbreviation for 'Regular Expression'", "RegExp");
+    QString matchCase = m_editWidget->matchCaseCheckBox->isChecked()?i18n("Yes"):i18n("No");
     QString match = m_editWidget->matchLineEdit->text();
     QString subst = m_editWidget->substLineEdit->text();
     delete m_editDlg;
     m_editDlg = 0;
     m_editWidget = 0;
     if (dlgResult != QDialog::Accepted) return;
-    // TODO: Also delete hBox and w?
+    // TODO: Also delete QTableWidget and w?
     if ( match.isEmpty() ) return;
     if ( isAdd )
     {
-        if ( item )
-            item = new KListViewItem( m_widget->substLView, item, substType, matchCase, match, subst );
-        else
-            item = new KListViewItem( m_widget->substLView, substType, matchCase, match, subst );
-        m_widget->substLView->setSelected( item, true );
+        row = substLView->rowCount();
+        substLView->setRowCount(row + 1);
+        substLView->setCurrentItem(substLView->item(row, 0));
+        for (int i = 0; i <= 4; ++i)
+            substLView->setItem(row, i, new QTableWidgetItem(""));
     }
-    else
-    {
-        item->setText( 0, substType );
-        item->setText( 1, matchCase );
-        item->setText( 2, match );
-        item->setText( 3, subst );
-    }
-    m_widget->substLView->ensureItemVisible( item );
+    substLView->item(row, 0)->setText(substType);
+    substLView->item(row, 1)->setText(matchCase);
+    substLView->item(row, 2)->setText(match);
+    substLView->item(row, 3)->setText(subst);
+    // TODO: Is this needed? substLView->scrollTo(substLView->indexFromItem(substLView->item(row,0)));
     enableDisableButtons();
     configChanged();
 }
@@ -641,14 +636,18 @@ void StringReplacerConf::slotMatchLineEdit_textChanged(const QString& text)
 {
     // Disable OK button if match field blank.
     if ( !m_editDlg ) return;
-    m_editDlg->enableButton( KDialogBase::Ok, !text.isEmpty() );
+    m_editDlg->enableButton( KDialog::Ok, !text.isEmpty() );
 }
 
 void StringReplacerConf::slotRemoveButton_clicked()
 {
-    QListViewItem* item = m_widget->substLView->selectedItem();
-    if (!item) return;
-    delete item;
+    int row = substLView->currentRow();
+    if (row <= 0 || row >= substLView->rowCount()) return;
+    delete substLView->takeItem(row, 0);
+    delete substLView->takeItem(row, 1);
+    delete substLView->takeItem(row, 2);
+    delete substLView->takeItem(row, 3);
+    substLView->removeRow(row);
     enableDisableButtons();
     configChanged();
 }
@@ -657,7 +656,7 @@ void StringReplacerConf::slotTypeButtonGroup_clicked()
 {
     // Enable Regular Expression Editor button if editor is installed (requires kdeutils).
     if ( !m_editWidget ) return;
-    m_editWidget->matchButton->setEnabled( m_editWidget->regexpRadioButton->isOn() &&  m_reEditorInstalled );
+    m_editWidget->matchButton->setEnabled( m_editWidget->regexpRadioButton->isChecked() &&  m_reEditorInstalled );
 }
 
 void StringReplacerConf::slotMatchButton_clicked()
@@ -667,12 +666,12 @@ void StringReplacerConf::slotMatchButton_clicked()
     if ( !m_editDlg ) return;
     if ( !m_reEditorInstalled ) return;
     QDialog *editorDialog = 
-        KParts::ComponentFactory::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor" );
+        KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor" );
     if ( editorDialog )
     {
         // kdeutils was installed, so the dialog was found.  Fetch the editor interface.
-        KRegExpEditorInterface *reEditor =
-            static_cast<KRegExpEditorInterface *>(editorDialog->qt_cast( "KRegExpEditorInterface" ) );
+
+        KRegExpEditorInterface *reEditor = qobject_cast<KRegExpEditorInterface*>( editorDialog );
         Q_ASSERT( reEditor ); // This should not fail!// now use the editor.
         reEditor->setRegExp( m_editWidget->matchLineEdit->text() );
         int dlgResult = editorDialog->exec();
@@ -680,7 +679,7 @@ void StringReplacerConf::slotMatchButton_clicked()
         {
             QString re = reEditor->regExp();
             m_editWidget->matchLineEdit->setText( re );
-            m_editDlg->enableButton( KDialogBase::Ok, !re.isEmpty() );
+            m_editDlg->enableButton( KDialog::Ok, !re.isEmpty() );
         }
         delete editorDialog;
     } else return;
@@ -688,18 +687,19 @@ void StringReplacerConf::slotMatchButton_clicked()
 
 void StringReplacerConf::slotLoadButton_clicked()
 {
-    // QString dataDir = KGlobal::dirs()->resourceDirs("data").last() + "/kttsd/stringreplacer/";
-    QString dataDir = KGlobal::dirs()->findAllResources("data", "kttsd/stringreplacer/").last();
+    QStringList dataDirs = KGlobal::dirs()->findAllResources("data", "kttsd/stringreplacer/");
+    QString dataDir;
+    if (!dataDirs.isEmpty()) dataDir = dataDirs.last();
     QString filename = KFileDialog::getOpenFileName(
         dataDir,
         "*.xml|String Replacer Word List (*.xml)",
-        m_widget,
+        this,
         "stringreplacer_loadfile");
     if ( filename.isEmpty() ) return;
     QString errMsg = loadFromFile( filename, false );
     enableDisableButtons();
     if ( !errMsg.isEmpty() )
-        KMessageBox::sorry( m_widget, errMsg, i18n("Error Opening File") );
+        KMessageBox::sorry( this, errMsg, i18n("Error Opening File") );
     else
         configChanged();
 }
@@ -709,17 +709,18 @@ void StringReplacerConf::slotSaveButton_clicked()
     QString filename = KFileDialog::getSaveFileName(
             KGlobal::dirs()->saveLocation( "data" ,"kttsd/stringreplacer/", false ),
            "*.xml|String Replacer Word List (*.xml)",
-            m_widget,
+            this,
             "stringreplacer_savefile");
     if ( filename.isEmpty() ) return;
     QString errMsg = saveToFile( filename );
     enableDisableButtons();
     if ( !errMsg.isEmpty() )
-        KMessageBox::sorry( m_widget, errMsg, i18n("Error Opening File") );
+        KMessageBox::sorry( this, errMsg, i18n("Error Opening File") );
 }
 
 void StringReplacerConf::slotClearButton_clicked()
 {
-    m_widget->substLView->clear();
+    substLView->setRowCount(0);
     enableDisableButtons();
 }
+
