@@ -26,11 +26,10 @@
 #define _STRINGREPLACERPROC_H_
 
 // Qt includes.
-#include <qobject.h>
-#include <qtextstream.h>
-#include <qvaluelist.h>
-#include <qregexp.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
+#include <QtCore/QList>
 
 // KTTS includes.
 #include "filterproc.h"
@@ -43,7 +42,7 @@ public:
     /**
      * Constructor.
      */
-    StringReplacerProc( QObject *parent, const char *name, const QStringList &args = QStringList() );
+    explicit StringReplacerProc( QObject *parent, const QStringList &args = QStringList() );
 
     /**
      * Destructor.
@@ -70,7 +69,7 @@ public:
      * @param appId             The DCOP appId of the application that queued the text.
      *                          Also useful for hints about how to do the filtering.
      */
-    virtual QString convert(const QString& inputText, TalkerCode* talkerCode, const QCString& appId);
+    virtual QString convert(const QString& inputText, TalkerCode* talkerCode, const QString& appId);
 
     /**
      * Did this filter do anything?  If the filter returns the input as output
@@ -85,11 +84,9 @@ private:
     QStringList m_appIdList;
 
     // List of regular expressions to match.
-    QValueList<QRegExp> m_matchList;
-    // List of match case flag
-    QValueList<QString> m_caseList;
+    QList<QRegExp> m_matchList;
     // List of substitutions to replace matches.
-    QValueList<QString> m_substList;
+    QList<QString> m_substList;
     // True if this filter did anything to the text.
     bool m_wasModified;
 };
