@@ -25,7 +25,7 @@
 #define _TALKERCHOOSERCONF_H_
 
 // Qt includes.
-#include <qwidget.h>
+#include <QtGui/QWidget>
 
 // KDE includes.
 #include <kconfig.h>
@@ -34,15 +34,12 @@
 // KTTS includes.
 #include "filterconf.h"
 #include "talkercode.h"
-#include "selecttalkerdlg.h"
 
 // TalkerChooser includes.
-#include "talkerchooserconfwidget.h"
+#include "ui_talkerchooserconfwidget.h"
 
-class KDialogBase;
-class EditReplacementWidget;
 
-class TalkerChooserConf : public KttsFilterConf
+class TalkerChooserConf : public KttsFilterConf, public Ui::TalkerChooserConfWidget
 {
     Q_OBJECT
 
@@ -50,7 +47,7 @@ class TalkerChooserConf : public KttsFilterConf
         /**
         * Constructor 
         */
-        TalkerChooserConf( QWidget *parent, const char *name, const QStringList &args = QStringList() );
+        explicit TalkerChooserConf( QWidget *parent, const QStringList &args = QStringList() );
 
         /**
         * Destructor 
@@ -123,8 +120,6 @@ class TalkerChooserConf : public KttsFilterConf
         void slotClearButton_clicked();
 
     private:
-        // Configuration Widget.
-        TalkerChooserConfWidget*    m_widget;
         // True if kdeutils Regular Expression Editor is installed.
         bool                        m_reEditorInstalled;
         // User's chosen Talker Code.
