@@ -19,16 +19,17 @@
 #ifndef _PLUGINPROC_H_
 #define _PLUGINPROC_H_
 
-#include <qobject.h>
-#include <qstring.h>
+// Qt includes.
+#include <QtCore/QObject>
+
+// KDE includes.
 #include <kdemacros.h>
-#include "kdeexportfix.h"
 #include <kconfig.h>
 
 /**
 * @interface PlugInProc
 *
-* pluginproc - the KDE Text-to-Speech Deamon Plugin API.
+* pluginproc - the KDE Text-to-Speech Daemon Plugin API.
 *
 * @version 1.0 Draft 1
 *
@@ -112,7 +113,7 @@
 * If @ref supportsAsync returns False, KTTSD will run the plugin in a separate
 * QThread.  As a consequence, the plugin must not make use of the KDE Library,
 * when @ref sayText or @ref synthText is called,
-* with the exception of KProcess and family (KProcIO, KShellProcess).
+* with the exception of K3Process and family (K3ProcIO, K3ShellProcess).
 * This restriction comes about because the KDE Libraries make use of the
 * main Qt event loop, which unfortunately, runs only in the main thread.
 * This restriction will likely be lifted in Qt 4 and later.
@@ -227,7 +228,7 @@ enum pluginState
     psFinished = 3               /**< Plugin has finished synthesizing.  Audio file is ready. */
 };
 
-class KDE_EXPORT PlugInProc : virtual public QObject{
+class KDE_EXPORT PlugInProc : public QObject{
     Q_OBJECT
 
     public:
@@ -259,7 +260,7 @@ class KDE_EXPORT PlugInProc : virtual public QObject{
           @verbatim
             config->setGroup(configGroup);
             m_fliteExePath = config->readEntry("FliteExePath", "flite");
-            kdDebug() << "FliteProc::init: path to flite: " << m_fliteExePath << endl;
+            kDebug() << "FliteProc::init: path to flite: " << m_fliteExePath;
             config->setGroup(configGroup);
           @endverbatim
         */
