@@ -23,15 +23,15 @@
  ******************************************************************************/
 
 // Qt includes.
-#include <qfile.h>
+#include <QtCore/QFile>
+#include <QtGui/QApplication>
 
 // KDE includes.
-#include <kapplication.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kstandarddirs.h>
 #include <kparts/componentfactory.h>
-#include <ktrader.h>
 #include <kdebug.h>
+#include <kservicetypetrader.h>
 
 // KTTS includes.
 #include "player.h"
@@ -46,8 +46,9 @@
  */
 TestPlayer::TestPlayer(QObject *parent, const char *name,
     const int playerOption, const float audioStretchFactor, const QString &sinkName) :
-    QObject(parent, name)
+    QObject(parent)
 {
+    setObjectName(name);
     m_playerOption = playerOption;
     m_audioStretchFactor = audioStretchFactor;
     m_stretcher = 0;
@@ -66,10 +67,8 @@ TestPlayer::~TestPlayer()
 
 /**
  * Sets which audio player to use.
- *  0 = aRts
- *  1 = gstreamer
+ *  0 = Phonon
  *  2 = ALSA
- *  3 = aKode
  */
 void TestPlayer::setPlayerOption(const int playerOption) { m_playerOption = playerOption; }
 
@@ -91,14 +90,14 @@ void TestPlayer::setSinkName(const QString &sinkName) { m_sinkName = sinkName; }
  */
 void TestPlayer::play(const QString &waveFile)
 {
-    // kdDebug() << "TestPlayer::play: running" << endl;
+    // kDebug() << "TestPlayer::play: running";
     // Create a Stretcher object to adjust the audio Speed.
     QString playFile = waveFile;
     QString tmpFile;
     if (m_audioStretchFactor != 1.0)
     {
         tmpFile = makeSuggestedFilename();
-        // kdDebug() << "TestPlayer::play: stretching file " << playFile << " by " << m_audioStretchFactor
+        // kDebug() << "TestPlayer::play: stretching file " << playFile << " by " << m_audioStretchFactor
         //     << " to file " << tmpFile << endl;
         m_stretcher = new Stretcher();
         if (m_stretcher->stretch(playFile, tmpFile, m_audioStretchFactor))
@@ -111,11 +110,11 @@ void TestPlayer::play(const QString &waveFile)
     }
 
     // Create player object based on player option.
-    // kdDebug() << "TestPlayer::play: creating Player object with playerOption " << m_playerOption << endl;
+    // kDebug() << "TestPlayer::play: creating Player object with playerOption " << m_playerOption;
     m_player = createPlayerObject(m_playerOption);
     // If player object could not be created, avoid crash is the best we can do!
     if (!m_player) return;
-    // kdDebug() << "TestPlayer::play: starting playback." << endl;
+    // kDebug() << "TestPlayer::play: starting playback.";
     m_player->startPlay(playFile);
 
     // TODO: The following hunk of code would ideally be unnecessary.  We would just
@@ -124,7 +123,7 @@ void TestPlayer::play(const QString &waveFile)
     // this seems to be necessary.  The call to processEvents is problematic because
     // it can cause re-entrancy.
     while (m_player->playing()) qApp->processEvents();
-    // kdDebug() << "TestPlayer::play: stopping playback." << endl;
+    // kDebug() << "TestPlayer::play: stopping playback.";
     m_player->stop();
     delete m_player;
     m_player = 0;
@@ -140,9 +139,9 @@ Player* TestPlayer::createPlayerObject(int playerOption)
     QString plugInName;
     switch(playerOption)
     {
-        case 1 :
+        case 0 :
         {
-            plugInName = "kttsd_gstplugin";
+            plugInName = "kttsd_phononplugin";
             break;
         }
         case 2 :
@@ -150,44 +149,30 @@ Player* TestPlayer::createPlayerObject(int playerOption)
             plugInName = "kttsd_alsaplugin";
             break;
         }
-        case 3 :
-        {
-            plugInName = "kttsd_akodeplugin";
-            break;
-        }
         default:
         {
-            plugInName = "kttsd_artsplugin";
+            // Default to Phonon.
+            plugInName = "kttsd_phononplugin";
             break;
         }
     }
-    KTrader::OfferList offers = KTrader::self()->query(
+	KService::List offers = KServiceTypeTrader::self()->query(
             "KTTSD/AudioPlugin", QString("DesktopEntryName == '%1'").arg(plugInName));
 
     if(offers.count() == 1)
     {
-        // kdDebug() << "TestPlayer::createPlayerObject: Loading " << offers[0]->library() << endl;
-        KLibFactory *factory = KLibLoader::self()->factory(offers[0]->library().latin1());
+        // kDebug() << "TestPlayer::createPlayerObject: Loading " << offers[0]->library();
+        KLibFactory *factory = KLibLoader::self()->factory(offers[0]->library().toLatin1());
         if (factory)
             player = 
-                KParts::ComponentFactory::createInstanceFromLibrary<Player>(
-                    offers[0]->library().latin1(), this, offers[0]->library().latin1());
+                KLibLoader::createInstance<Player>(
+                    offers[0]->library().toLatin1(), this, QStringList(offers[0]->library().toLatin1()));
         else
-            kdDebug() << "TestPlayer::createPlayerObject: Could not create factory." << endl;
+            kDebug() << "TestPlayer::createPlayerObject: Could not create factory.";
     }
     if (player == 0)
-        kdDebug() << "TestPlayer::createPlayerObject: Could not load " + plugInName +
+        kDebug() << "TestPlayer::createPlayerObject: Could not load " + plugInName +
             ".  Is KDEDIRS set correctly?" << endl;
-    else
-        // Must have GStreamer >= 0.8.7.
-        if (playerOption == 1)
-        {
-            if (!player->requireVersion(0, 8, 7))
-            {
-                delete player;
-                player = 0;
-            }
-        }
     if (player) player->setSinkName(m_sinkName);
     return player;
 }
@@ -199,11 +184,13 @@ Player* TestPlayer::createPlayerObject(int playerOption)
  */
 QString TestPlayer::makeSuggestedFilename()
 {
-    KTempFile tempFile (locateLocal("tmp", "kttsmgr-"), ".wav");
-    QString waveFile = tempFile.file()->name();
-    tempFile.close();
-    QFile::remove(waveFile);
-    // kdDebug() << "TestPlayer::makeSuggestedFilename: Suggesting filename: " << waveFile << endl;
+    KTemporaryFile *tempFile = new KTemporaryFile();
+    tempFile->setPrefix("kttsmgr-");
+    tempFile->setSuffix(".wav");
+    tempFile->open();
+    QString waveFile = tempFile->fileName();
+    delete tempFile;
+    // kDebug() << "TestPlayer::makeSuggestedFilename: Suggesting filename: " << waveFile;
     return PlugInConf::realFilePath(waveFile);
 }
 
