@@ -20,5 +20,5 @@
 #include "commandproc.h"
 
 typedef K_TYPELIST_2( CommandProc, CommandConf ) Command;
-K_EXPORT_COMPONENT_FACTORY( libkttsd_commandplugin, KGenericFactory<Command>("kttsd_command") )
+K_EXPORT_COMPONENT_FACTORY( libkttsd_commandplugin, KGenericFactory<Command>("kttsd") )
 
