@@ -26,27 +26,25 @@
 #include <math.h>
 
 // Qt includes.
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qtextcodec.h>
-#include <qfile.h>
-#include <qtextcodec.h>
+#include <QtCore/QTextCodec>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 // KDE includes.
 #include <kdebug.h>
 #include <kconfig.h>
-#include <ktempfile.h>
+#include <kconfiggroup.h>
 #include <kstandarddirs.h>
-#include <kprocess.h>
+#include <k3process.h>
 
 // Epos Plugin includes.
 #include "eposproc.h"
 #include "eposproc.moc"
  
 /** Constructor */
-EposProc::EposProc( QObject* parent, const char* name, const QStringList& ) : 
-    PlugInProc( parent, name ){
-    kdDebug() << "EposProc::EposProc: Running" << endl;
+EposProc::EposProc( QObject* parent, const QStringList& ) : 
+    PlugInProc( parent, "eposproc" ){
+    kDebug() << "EposProc::EposProc: Running";
     m_state = psIdle;
     m_waitingStop = false;
     m_eposServerProc = 0;
@@ -55,7 +53,7 @@ EposProc::EposProc( QObject* parent, const char* name, const QStringList& ) :
 
 /** Destructor */
 EposProc::~EposProc(){
-    kdDebug() << "EposProc::~EposProc:: Running" << endl;
+    kDebug() << "EposProc::~EposProc:: Running";
     if (m_eposProc)
     {
         stopText();
@@ -65,39 +63,39 @@ EposProc::~EposProc(){
 }
 
 /** Initialize the speech */
-bool EposProc::init(KConfig* config, const QString& configGroup)
+bool EposProc::init(KConfig* c, const QString& configGroup)
 {
-    // kdDebug() << "EposProc::init: Running" << endl;
-    // kdDebug() << "Initializing plug in: Epos" << endl;
+    // kDebug() << "EposProc::init: Running";
+    // kDebug() << "Initializing plug in: Epos";
     // Retrieve path to epos executable.
-    config->setGroup(configGroup);
-    m_eposServerExePath = config->readEntry("EposServerExePath", "epos");
-    m_eposClientExePath = config->readEntry("EposClientExePath", "say");
-    m_eposLanguage = config->readEntry("Language", QString::null);
-    m_time = config->readNumEntry("time", 100);
-    m_pitch = config->readNumEntry("pitch", 100);
-    m_eposServerOptions = config->readEntry("EposServerOptions", QString::null);
-    m_eposClientOptions = config->readEntry("EposClientOptions", QString::null);
-    kdDebug() << "EposProc::init: path to epos server: " << m_eposServerExePath << endl;
-    kdDebug() << "EposProc::init: path to epos client: " << m_eposClientExePath << endl;
+    KConfigGroup config(c, configGroup);
+    m_eposServerExePath = config.readEntry("EposServerExePath", "epos");
+    m_eposClientExePath = config.readEntry("EposClientExePath", "say");
+    m_eposLanguage = config.readEntry("Language", QString());
+    m_time = config.readEntry("time", 100);
+    m_pitch = config.readEntry("pitch", 100);
+    m_eposServerOptions = config.readEntry("EposServerOptions", QString());
+    m_eposClientOptions = config.readEntry("EposClientOptions", QString());
+    kDebug() << "EposProc::init: path to epos server: " << m_eposServerExePath;
+    kDebug() << "EposProc::init: path to epos client: " << m_eposClientExePath;
 
-    QString codecString = config->readEntry("Codec", "Local");
+    QString codecString = config.readEntry("Codec", "Local");
     m_codec = codecNameToCodec(codecString);
     // Start the Epos server if not already started.
     if (!m_eposServerProc)
     {
-        KProcess* m_eposServerProc = new KProcess;
+        K3Process* m_eposServerProc = new K3Process;
         *m_eposServerProc << m_eposServerExePath;
         if (!m_eposServerOptions.isEmpty())
             *m_eposServerProc << m_eposServerOptions;
-        connect(m_eposServerProc, SIGNAL(receivedStdout(KProcess*, char*, int)),
-            this, SLOT(slotReceivedStdout(KProcess*, char*, int)));
-        connect(m_eposServerProc, SIGNAL(receivedStderr(KProcess*, char*, int)),
-            this, SLOT(slotReceivedStderr(KProcess*, char*, int)));
-        m_eposServerProc->start(KProcess::DontCare, KProcess::AllOutput);
+        connect(m_eposServerProc, SIGNAL(receivedStdout(K3Process*, char*, int)),
+            this, SLOT(slotReceivedStdout(K3Process*, char*, int)));
+        connect(m_eposServerProc, SIGNAL(receivedStderr(K3Process*, char*, int)),
+            this, SLOT(slotReceivedStderr(K3Process*, char*, int)));
+        m_eposServerProc->start(K3Process::DontCare, K3Process::AllOutput);
     }
 
-    kdDebug() << "EposProc::init: Initialized with codec: " << codecString << endl;
+    kDebug() << "EposProc::init: Initialized with codec: " << codecString;
 
     return true;
 }
@@ -110,7 +108,7 @@ bool EposProc::init(KConfig* config, const QString& configGroup)
 */
 void EposProc::sayText(const QString &text)
 {
-    synth(text, QString::null, m_eposServerExePath, m_eposClientExePath,
+    synth(text, QString(), m_eposServerExePath, m_eposClientExePath,
         m_eposServerOptions, m_eposClientOptions,
         m_codec, m_eposLanguage, m_time, m_pitch);
 }
@@ -159,7 +157,7 @@ void EposProc::synth(
     int time,
     int pitch)
 {
-    // kdDebug() << "Running: EposProc::synth(const QString &text)" << endl;
+    // kDebug() << "Running: EposProc::synth(const QString &text)";
 
     if (m_eposProc)
     {
@@ -170,30 +168,30 @@ void EposProc::synth(
     // Start the Epos server if not already started.
     if (!m_eposServerProc)
     {
-        KProcess* m_eposServerProc = new KProcess;
+        K3Process* m_eposServerProc = new K3Process;
         *m_eposServerProc << eposServerExePath;
         if (!eposServerOptions.isEmpty())
             *m_eposServerProc << eposServerOptions;
-        connect(m_eposServerProc, SIGNAL(receivedStdout(KProcess*, char*, int)),
-            this, SLOT(slotReceivedStdout(KProcess*, char*, int)));
-        connect(m_eposServerProc, SIGNAL(receivedStderr(KProcess*, char*, int)),
-            this, SLOT(slotReceivedStderr(KProcess*, char*, int)));
-        m_eposServerProc->start(KProcess::DontCare, KProcess::AllOutput);
+        connect(m_eposServerProc, SIGNAL(receivedStdout(K3Process*, char*, int)),
+            this, SLOT(slotReceivedStdout(K3Process*, char*, int)));
+        connect(m_eposServerProc, SIGNAL(receivedStderr(K3Process*, char*, int)),
+            this, SLOT(slotReceivedStderr(K3Process*, char*, int)));
+        m_eposServerProc->start(K3Process::DontCare, K3Process::AllOutput);
     }
 
     // Encode the text.
     // 1.a) encode the text
-    m_encText = QCString();
-    QTextStream ts (m_encText, IO_WriteOnly);
+    m_encText = QByteArray();
+    QTextStream ts (m_encText, QIODevice::WriteOnly);
     ts.setCodec(codec);
     ts << text;
     ts << endl; // Some synths need this, eg. flite.
 
     // Quote the text as one parameter.
-    // QString escText = KShellProcess::quote(encText);
+    // QString escText = K3ShellProcess::quote(encText);
 
-    // kdDebug()<< "EposProc::synth: Creating Epos object" << endl;
-    m_eposProc = new KProcess;
+    // kDebug()<< "EposProc::synth: Creating Epos object";
+    m_eposProc = new K3Process;
     m_eposProc->setUseShell(true);
     QString languageCode;
     if (eposLanguage == "czech")
@@ -202,8 +200,8 @@ void EposProc::synth(
         languageCode == "sk";
     if (!languageCode.isEmpty())
     {
-        m_eposProc->setEnvironment("LANG", languageCode + "." + codec->mimeName());
-        m_eposProc->setEnvironment("LC_CTYPE", languageCode + "." + codec->mimeName());
+        m_eposProc->setEnvironment("LANG", languageCode + '.' + codec->name());
+        m_eposProc->setEnvironment("LC_CTYPE", languageCode + '.' + codec->name());
     }
     *m_eposProc << eposClientExePath;
     // Language.
@@ -232,14 +230,14 @@ void EposProc::synth(
     *m_eposProc << "-";   // Read from StdIn.
     if (!suggestedFilename.isEmpty()) 
         *m_eposProc << " >" + suggestedFilename;
-    connect(m_eposProc, SIGNAL(processExited(KProcess*)),
-        this, SLOT(slotProcessExited(KProcess*)));
-    connect(m_eposProc, SIGNAL(receivedStdout(KProcess*, char*, int)),
-        this, SLOT(slotReceivedStdout(KProcess*, char*, int)));
-    connect(m_eposProc, SIGNAL(receivedStderr(KProcess*, char*, int)),
-        this, SLOT(slotReceivedStderr(KProcess*, char*, int)));
-    connect(m_eposProc, SIGNAL(wroteStdin(KProcess*)),
-        this, SLOT(slotWroteStdin(KProcess* )));
+    connect(m_eposProc, SIGNAL(processExited(K3Process*)),
+        this, SLOT(slotProcessExited(K3Process*)));
+    connect(m_eposProc, SIGNAL(receivedStdout(K3Process*, char*, int)),
+        this, SLOT(slotReceivedStdout(K3Process*, char*, int)));
+    connect(m_eposProc, SIGNAL(receivedStderr(K3Process*, char*, int)),
+        this, SLOT(slotReceivedStderr(K3Process*, char*, int)));
+    connect(m_eposProc, SIGNAL(wroteStdin(K3Process*)),
+        this, SLOT(slotWroteStdin(K3Process* )));
     if (suggestedFilename.isEmpty())
         m_state = psSaying;
     else
@@ -247,16 +245,16 @@ void EposProc::synth(
 
     // Ok, let's rock.
     m_synthFilename = suggestedFilename;
-    kdDebug() << "EposProc::synth: Synthing text: '" << text << "' using Epos plug in" << endl;
-    if (!m_eposProc->start(KProcess::NotifyOnExit, KProcess::All))
+    kDebug() << "EposProc::synth: Synthing text: '" << text << "' using Epos plug in";
+    if (!m_eposProc->start(K3Process::NotifyOnExit, K3Process::All))
     {
-        kdDebug() << "EposProc::synth: Error starting Epos process.  Is epos in the PATH?" << endl;
+        kDebug() << "EposProc::synth: Error starting Epos process.  Is epos in the PATH?";
         m_state = psIdle;
         return;
     }
-    kdDebug()<< "EposProc:synth: Epos initialized" << endl;
+    kDebug()<< "EposProc:synth: Epos initialized";
     if (!m_eposProc->writeStdin(m_encText, m_encText.length()))
-        kdDebug() << "EposProc::synth: Error writing to Epos client StdIn." << endl;
+        kDebug() << "EposProc::synth: Error writing to Epos client StdIn.";
 }
 
 /**
@@ -268,7 +266,7 @@ void EposProc::synth(
 */
 QString EposProc::getFilename()
 {
-    kdDebug() << "EposProc::getFilename: returning " << m_synthFilename << endl;
+    kDebug() << "EposProc::getFilename: returning " << m_synthFilename;
     return m_synthFilename;
 }
 
@@ -288,22 +286,22 @@ QString EposProc::getFilename()
 * operation.
 */
 void EposProc::stopText(){
-    kdDebug() << "EposProc::stopText:: Running" << endl;
+    kDebug() << "EposProc::stopText:: Running";
     if (m_eposProc)
     {
         if (m_eposProc->isRunning())
         {
-            kdDebug() << "EposProc::stopText: killing Epos." << endl;
+            kDebug() << "EposProc::stopText: killing Epos.";
             m_waitingStop = true;
             m_eposProc->kill();
         } else m_state = psIdle;
     } else m_state = psIdle;
-    kdDebug() << "EposProc::stopText: Epos stopped." << endl;
+    kDebug() << "EposProc::stopText: Epos stopped.";
 }
 
-void EposProc::slotProcessExited(KProcess*)
+void EposProc::slotProcessExited(K3Process*)
 {
-    kdDebug() << "EposProc:slotProcessExited: Epos process has exited." << endl;
+    kDebug() << "EposProc:slotProcessExited: Epos process has exited.";
     pluginState prevState = m_state;
     if (m_waitingStop)
     {
@@ -320,23 +318,23 @@ void EposProc::slotProcessExited(KProcess*)
     }
 }
 
-void EposProc::slotReceivedStdout(KProcess*, char* buffer, int buflen)
+void EposProc::slotReceivedStdout(K3Process*, char* buffer, int buflen)
 {
     QString buf = QString::fromLatin1(buffer, buflen);
-    kdDebug() << "EposProc::slotReceivedStdout: Received output from Epos: " << buf << endl;
+    kDebug() << "EposProc::slotReceivedStdout: Received output from Epos: " << buf;
 }
 
-void EposProc::slotReceivedStderr(KProcess*, char* buffer, int buflen)
+void EposProc::slotReceivedStderr(K3Process*, char* buffer, int buflen)
 {
     QString buf = QString::fromLatin1(buffer, buflen);
-    kdDebug() << "EposProc::slotReceivedStderr: Received error from Epos: " << buf << endl;
+    kDebug() << "EposProc::slotReceivedStderr: Received error from Epos: " << buf;
 }
 
-void EposProc::slotWroteStdin(KProcess*)
+void EposProc::slotWroteStdin(K3Process*)
 {
-    kdDebug() << "EposProc::slotWroteStdin: closing Stdin" << endl;
+    kDebug() << "EposProc::slotWroteStdin: closing Stdin";
     m_eposProc->closeStdin();
-    m_encText = QCString();
+    m_encText = QByteArray();
 }
 
 /**
@@ -361,7 +359,7 @@ void EposProc::ackFinished()
     if (m_state == psFinished)
     {
         m_state = psIdle;
-        m_synthFilename = QString::null;
+        m_synthFilename.clear();
     }
 }
 
