@@ -25,28 +25,25 @@
 #include <math.h>
 
 // Qt includes.
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qcheckbox.h>
-#include <qdir.h>
-#include <qslider.h>
-#include <qdom.h>
-#include <qtextcodec.h>
+#include <QtGui/QLabel>
+#include <QtGui/QCheckBox>
+#include <QtCore/QDir>
+#include <QtGui/QSlider>
+#include <QtXml/qdom.h>
+#include <QtCore/QTextCodec>
+#include <QtGui/QPixmap>
 
 // KDE includes.
-#include <kdialog.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kcombobox.h>
 #include <kglobal.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kstandarddirs.h>
 #include <knuminput.h>
-#include <kprocio.h>
-#include <kprogress.h>
-#include <kiconloader.h>
+#include <k3procio.h>
+#include <kprogressdialog.h>
+#include <kicon.h>
 
 // KTTS includes.
 #include "testplayer.h"
@@ -57,66 +54,62 @@
 #include "festivalintconf.moc"
 
 /** Constructor */
-FestivalIntConf::FestivalIntConf( QWidget* parent, const char* name, const QStringList& /*args*/) :
-    PlugInConf(parent, name)
+FestivalIntConf::FestivalIntConf( QWidget* parent, const QStringList& /*args*/) :
+    PlugInConf(parent, "festivalintconf")
 {
-    // kdDebug() << "FestivalIntConf::FestivalIntConf: Running" << endl;
+    // kDebug() << "FestivalIntConf::FestivalIntConf: Running";
     m_festProc = 0;
     m_progressDlg = 0;
     m_supportsSSML = FestivalIntProc::ssUnknown;
 
-    QVBoxLayout *layout = new QVBoxLayout(this, KDialog::marginHint(),
-        KDialog::spacingHint(), "FestivalIntConfigWidgetLayout");
-    layout->setAlignment (Qt::AlignTop);
-    m_widget = new FestivalIntConfWidget(this, "FestivalIntConfigWidget");
-    layout->addWidget(m_widget);
+    setupUi(this);
 
-    m_widget->festivalPath->setMode(KFile::File | KFile::ExistingOnly);
-    m_widget->festivalPath->setFilter("*");
+    festivalPath->setMode(KFile::File | KFile::ExistingOnly);
+    festivalPath->setFilter("*");
 
     // Build codec list and fill combobox.
     m_codecList = PlugInProc::buildCodecList();
-    m_widget->characterCodingBox->clear();
-    m_widget->characterCodingBox->insertStringList(m_codecList);
+    characterCodingBox->clear();
+    characterCodingBox->addItems(m_codecList);
 
     //    defaults();
 
-    connect(m_widget->festivalPath, SIGNAL(textChanged(const QString&)),
+    connect(festivalPath, SIGNAL(textChanged(const QString&)),
             this, SLOT(slotFestivalPath_textChanged()));
-    connect(m_widget->selectVoiceCombo, SIGNAL(activated(const QString&)),
+    connect(selectVoiceCombo, SIGNAL(activated(const QString&)),
             this, SLOT(slotSelectVoiceCombo_activated()));
-    connect(m_widget->selectVoiceCombo, SIGNAL(activated(const QString&)),
+    connect(selectVoiceCombo, SIGNAL(activated(const QString&)),
             this, SLOT(configChanged()));
-    connect(m_widget->testButton, SIGNAL(clicked()), this, SLOT(slotTest_clicked()));
-    connect(m_widget->rescan, SIGNAL(clicked()), this, SLOT(scanVoices()));
-    connect(m_widget->volumeBox, SIGNAL(valueChanged(int)),
+    connect(testButton, SIGNAL(clicked()), this, SLOT(slotTest_clicked()));
+    connect(rescan, SIGNAL(clicked()), this, SLOT(scanVoices()));
+    connect(volumeBox, SIGNAL(valueChanged(int)),
             this, SLOT(volumeBox_valueChanged(int)));
-    connect(m_widget->timeBox, SIGNAL(valueChanged(int)),
+    connect(timeBox, SIGNAL(valueChanged(int)),
             this, SLOT(timeBox_valueChanged(int)));
-    connect(m_widget->frequencyBox, SIGNAL(valueChanged(int)),
+    connect(frequencyBox, SIGNAL(valueChanged(int)),
             this, SLOT(frequencyBox_valueChanged(int)));
-    connect(m_widget->volumeSlider, SIGNAL(valueChanged(int)),
+    connect(volumeSlider, SIGNAL(valueChanged(int)),
             this, SLOT(volumeSlider_valueChanged(int)));
-    connect(m_widget->timeSlider, SIGNAL(valueChanged(int)),
+    connect(timeSlider, SIGNAL(valueChanged(int)),
             this, SLOT(timeSlider_valueChanged(int)));
-    connect(m_widget->frequencySlider, SIGNAL(valueChanged(int)),
+    connect(frequencySlider, SIGNAL(valueChanged(int)),
             this, SLOT(frequencySlider_valueChanged(int)));
-    connect(m_widget->volumeBox, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
-    connect(m_widget->volumeSlider, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
-    connect(m_widget->timeBox, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
-    connect(m_widget->timeSlider, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
-    connect(m_widget->frequencyBox, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
-    connect(m_widget->frequencySlider, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
-    connect(m_widget->preloadCheckBox, SIGNAL(clicked()), this, SLOT(configChanged()));
-    connect(m_widget->characterCodingBox, SIGNAL(textChanged(const QString&)),
+    connect(volumeBox, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+    connect(volumeSlider, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+    connect(timeBox, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+    connect(timeSlider, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+    connect(frequencyBox, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+    connect(frequencySlider, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+    connect(preloadCheckBox, SIGNAL(clicked()), this, SLOT(configChanged()));
+    connect(characterCodingBox, SIGNAL(textChanged(const QString&)),
             this, SLOT(configChanged()));
-    connect(m_widget->characterCodingBox, SIGNAL(activated(const QString&)),
+    connect(characterCodingBox, SIGNAL(activated(const QString&)),
             this, SLOT(configChanged()));
 }
 
 /** Destructor */
 FestivalIntConf::~FestivalIntConf(){
-    // kdDebug() << "FestivalIntConf::~FestivalIntConf: Running" << endl;
+    // kDebug() << "FestivalIntConf::~FestivalIntConf: Running";
     if (!m_waveFile.isNull()) QFile::remove(m_waveFile);
     delete m_festProc;
     delete m_progressDlg;
@@ -128,103 +121,101 @@ FestivalIntConf::~FestivalIntConf(){
 */
 int FestivalIntConf::voiceCodeToListIndex(const QString& voiceCode) const
 {
-    const int voiceListCount = m_voiceList.count();
-    for(int index = 0; index < voiceListCount; ++index){
-        // kdDebug() << "Testing: " << voiceCode << " == " << m_voiceList[index].code << endl;
-        if(voiceCode == m_voiceList[index].code)
-            return index;
-    }
+    for (int i = 0; i < m_voiceList.size(); ++i)
+        if (m_voiceList[i].code == voiceCode) return i;
     return -1;
 }
 
-void FestivalIntConf::load(KConfig *config, const QString &configGroup){
-    //kdDebug() << "FestivalIntConf::load: Running" << endl;
-    config->setGroup("FestivalInt");
-    QString exePath = config->readEntry("FestivalExecutablePath", "festival");
+void FestivalIntConf::load(KConfig *c, const QString &configGroup){
+    //kDebug() << "FestivalIntConf::load: Running";
+    KConfigGroup festivalConfig(c, "FestivalInt");
+    QString exePath = festivalConfig.readEntry("FestivalExecutablePath", "festival");
     QString exeLocation = getLocation(exePath);
     if (!exeLocation.isEmpty()) exePath = exeLocation;
     exePath = realFilePath(exePath);
-    config->setGroup(configGroup);
-    m_widget->festivalPath->setURL(config->readEntry("FestivalExecutablePath", exePath));
-    m_widget->preloadCheckBox->setChecked(false);
+
+    KConfigGroup config(c, configGroup);
+    festivalPath->setUrl(KUrl::fromPath(config.readEntry("FestivalExecutablePath", exePath)));
+    preloadCheckBox->setChecked(false);
     scanVoices();
-    QString voiceSelected(config->readEntry("Voice"));
+    QString voiceSelected(config.readEntry("Voice"));
     int index = voiceCodeToListIndex(voiceSelected);
     if (index >= 0)
     {
-        m_widget->selectVoiceCombo->setCurrentItem(index);
-        m_widget->preloadCheckBox->setChecked(m_voiceList[index].preload);
+        selectVoiceCombo->setCurrentIndex(index);
+        preloadCheckBox->setChecked(m_voiceList[index].preload);
     }
-    m_widget->volumeBox->setValue(config->readNumEntry("volume", 100));
-    m_widget->timeBox->setValue(config->readNumEntry("time", 100));
-    m_widget->frequencyBox->setValue(config->readNumEntry("pitch", 100));
-    m_widget->preloadCheckBox->setChecked(config->readBoolEntry(
-        "Preload", m_widget->preloadCheckBox->isChecked()));
-    m_languageCode = config->readEntry("LanguageCode", m_languageCode);
+    volumeBox->setValue(config.readEntry("volume", 100));
+    timeBox->setValue(config.readEntry("time", 100));
+    frequencyBox->setValue(config.readEntry("pitch", 100));
+    preloadCheckBox->setChecked(config.readEntry(
+                "Preload", preloadCheckBox->isChecked()));
+    m_languageCode = config.readEntry("LanguageCode", m_languageCode);
     m_supportsSSML = static_cast<FestivalIntProc::SupportsSSML>(
-        config->readNumEntry("SupportsSSML", FestivalIntProc::ssUnknown));
+            config.readEntry("SupportsSSML", int(FestivalIntProc::ssUnknown)));
     QString codecName = PlugInProc::codecIndexToCodecName(
-        m_widget->characterCodingBox->currentItem(), m_codecList);
-    codecName = config->readEntry("Codec", codecName);
+            characterCodingBox->currentIndex(), m_codecList);
+    codecName = config.readEntry("Codec", codecName);
     int codecNdx = PlugInProc::codecNameToListIndex(codecName, m_codecList);
-    m_widget->characterCodingBox->setCurrentItem(codecNdx);
+    characterCodingBox->setCurrentIndex(codecNdx);
 }
 
-void FestivalIntConf::save(KConfig *config, const QString &configGroup){
-    // kdDebug() << "FestivalIntConf::save: Running" << endl;
-    config->setGroup("FestivalInt");
-    config->writeEntry("FestivalExecutablePath", realFilePath(m_widget->festivalPath->url()));
-    config->setGroup(configGroup);
-    config->writeEntry("FestivalExecutablePath", realFilePath(m_widget->festivalPath->url()));
-    config->writeEntry("Voice", m_voiceList[m_widget->selectVoiceCombo->currentItem()].code);
-    config->writeEntry("volume", m_widget->volumeBox->value());
-    config->writeEntry("time", m_widget->timeBox->value());
-    config->writeEntry("pitch", m_widget->frequencyBox->value());
-    config->writeEntry("Preload", m_widget->preloadCheckBox->isChecked());
-    config->writeEntry("LanguageCode", m_voiceList[m_widget->selectVoiceCombo->currentItem()].languageCode);
-    config->writeEntry("SupportsSSML", m_supportsSSML);
-    int codec = m_widget->characterCodingBox->currentItem();
-    config->writeEntry("Codec", PlugInProc::codecIndexToCodecName(codec, m_codecList));
+void FestivalIntConf::save(KConfig *c, const QString &configGroup){
+    // kDebug() << "FestivalIntConf::save: Running";
+    KConfigGroup festivalConfig(c, "FestivalInt");
+    festivalConfig.writeEntry("FestivalExecutablePath", realFilePath(festivalPath->url().path()));
+
+    KConfigGroup config(c, configGroup);
+    config.writeEntry("FestivalExecutablePath", realFilePath(festivalPath->url().path()));
+    config.writeEntry("Voice", m_voiceList[selectVoiceCombo->currentIndex()].code);
+    config.writeEntry("volume", volumeBox->value());
+    config.writeEntry("time", timeBox->value());
+    config.writeEntry("pitch", frequencyBox->value());
+    config.writeEntry("Preload", preloadCheckBox->isChecked());
+    config.writeEntry("LanguageCode", m_voiceList[selectVoiceCombo->currentIndex()].languageCode);
+    config.writeEntry("SupportsSSML", int(m_supportsSSML));
+    int codec = characterCodingBox->currentIndex();
+    config.writeEntry("Codec", PlugInProc::codecIndexToCodecName(codec, m_codecList));
 }
 
 void FestivalIntConf::defaults(){
-    // kdDebug() << "FestivalIntConf::defaults: Running" << endl;
-    m_widget->festivalPath->setURL("festival");
-    m_widget->timeBox->setValue(100);
+    // kDebug() << "FestivalIntConf::defaults: Running";
+    festivalPath->setUrl(KUrl("festival"));
+    timeBox->setValue(100);
     timeBox_valueChanged(100);
-    m_widget->volumeBox->setValue(100);
+    volumeBox->setValue(100);
     volumeBox_valueChanged(100);
-    m_widget->frequencyBox->setValue(100);
+    frequencyBox->setValue(100);
     frequencyBox_valueChanged(100);
-    m_widget->preloadCheckBox->setChecked(false);
-    m_widget->characterCodingBox->setCurrentItem(
+    preloadCheckBox->setChecked(false);
+    characterCodingBox->setCurrentIndex(
         PlugInProc::codecNameToListIndex("ISO 8859-1", m_codecList));
     scanVoices();
 }
 
 void FestivalIntConf::setDesiredLanguage(const QString &lang)
 {
-    // kdDebug() << "FestivalIntConf::setDesiredLanguage: Running" << endl;
+    // kDebug() << "FestivalIntConf::setDesiredLanguage: Running";
     m_languageCode = splitLanguageCode(lang, m_countryCode);
 }
 
 QString FestivalIntConf::getTalkerCode()
 {
-    if (!m_widget->selectVoiceCombo->isEnabled()) return QString::null;
-    QString exePath = realFilePath(m_widget->festivalPath->url());
-    if (exePath.isEmpty()) return QString::null;
-    if (getLocation(exePath).isEmpty()) return QString::null;
-    if (m_voiceList.count() == 0) return QString::null;
+    if (!selectVoiceCombo->isEnabled()) return QString();
+    QString exePath = realFilePath(festivalPath->url().path());
+    if (exePath.isEmpty()) return QString();
+    if (getLocation(exePath).isEmpty()) return QString();
+    if (m_voiceList.count() == 0) return QString();
     QString normalTalkerCode;
-    voiceStruct voiceTemp = m_voiceList[m_widget->selectVoiceCombo->currentItem()];
+    voiceStruct voiceTemp = m_voiceList[selectVoiceCombo->currentIndex()];
     // Determine volume attribute.  soft < 75% <= medium <= 125% < loud.
     QString volume = "medium";
-    if (m_widget->volumeBox->value() < 75) volume = "soft";
-    if (m_widget->volumeBox->value() > 125) volume = "loud";
+    if (volumeBox->value() < 75) volume = "soft";
+    if (volumeBox->value() > 125) volume = "loud";
     // Determine rate attribute.  slow < 75% <= medium <= 125% < fast.
     QString rate = "medium";
-    if (m_widget->timeBox->value() < 75) rate = "slow";
-    if (m_widget->timeBox->value() > 125) rate = "fast";
+    if (timeBox->value() < 75) rate = "slow";
+    if (timeBox->value() > 125) rate = "fast";
     normalTalkerCode = QString(
             "<voice lang=\"%1\" name=\"%2\" gender=\"%3\" />"
             "<prosody volume=\"%4\" rate=\"%5\" />"
@@ -245,16 +236,16 @@ QString FestivalIntConf::getTalkerCode()
  */
 void FestivalIntConf::setDefaultVoice(int currentVoiceIndex)
 {
-    // kdDebug() << "FestivalIntCont::setDefaultVoice: Running" << endl;
+    // kDebug() << "FestivalIntCont::setDefaultVoice: Running";
     // If language code is known, auto pick first voice that matches the language code.
     if (!m_languageCode.isEmpty())
     {
         bool found = false;
         // First search for a match on both language code and country code.
         QString languageCode = m_languageCode;
-        if (!m_countryCode.isNull()) languageCode += "_" + m_countryCode;
-        // kdDebug() << "FestivalIntConf::setDefaultVoice:: looking for default voice to match language code " << languageCode << endl;
-        uint index = 0;
+        if (!m_countryCode.isNull()) languageCode += '_' + m_countryCode;
+        // kDebug() << "FestivalIntConf::setDefaultVoice:: looking for default voice to match language code " << languageCode;
+        int index = 0;
         // Prefer existing voice if it matches.
         if (currentVoiceIndex >= 0)
         {
@@ -270,7 +261,7 @@ void FestivalIntConf::setDefaultVoice(int currentVoiceIndex)
             for(index = 0 ; index < m_voiceList.count(); ++index)
             {
                 QString vlCode = m_voiceList[index].languageCode.left(languageCode.length());
-                // kdDebug() << "FestivalIntConf::setDefaultVoice: testing " << vlCode << endl;
+                // kDebug() << "FestivalIntConf::setDefaultVoice: testing " << vlCode;
                 if(languageCode == vlCode)
                 {
                     found = true;
@@ -297,7 +288,7 @@ void FestivalIntConf::setDefaultVoice(int currentVoiceIndex)
                 for(index = 0 ; index < m_voiceList.count(); ++index)
                 {
                     QString vlCode = m_voiceList[index].languageCode.left(languageCode.length());
-                    // kdDebug() << "FestivalIntConf::setDefaultVoice: testing " << vlCode << endl;
+                    // kDebug() << "FestivalIntConf::setDefaultVoice: testing " << vlCode;
                     if(languageCode == vlCode)
                     {
                         found = true;
@@ -320,47 +311,47 @@ void FestivalIntConf::setDefaultVoice(int currentVoiceIndex)
         }
         if (found)
         {
-            // kdDebug() << "FestivalIntConf::setDefaultVoice: auto picking voice code " << m_voiceList[index].code << endl;
-            m_widget->selectVoiceCombo->setCurrentItem(index);
-            m_widget->preloadCheckBox->setChecked(m_voiceList[index].preload);
+            // kDebug() << "FestivalIntConf::setDefaultVoice: auto picking voice code " << m_voiceList[index].code;
+            selectVoiceCombo->setCurrentIndex(index);
+            preloadCheckBox->setChecked(m_voiceList[index].preload);
             QString codecName = m_voiceList[index].codecName;
             int codecNdx = PlugInProc::codecNameToListIndex(codecName, m_codecList);
-            m_widget->characterCodingBox->setCurrentItem(codecNdx);
+            characterCodingBox->setCurrentIndex(codecNdx);
             if (m_voiceList[index].volumeAdjustable)
             {
-                m_widget->volumeBox->setEnabled(true);
-                m_widget->volumeSlider->setEnabled(true);
+                volumeBox->setEnabled(true);
+                volumeSlider->setEnabled(true);
             }
             else
             {
-                m_widget->volumeBox->setValue(100);
+                volumeBox->setValue(100);
                 volumeBox_valueChanged(100);
-                m_widget->volumeBox->setEnabled(false);
-                m_widget->volumeSlider->setEnabled(false);
+                volumeBox->setEnabled(false);
+                volumeSlider->setEnabled(false);
             }
             if (m_voiceList[index].rateAdjustable)
             {
-                m_widget->timeBox->setEnabled(true);
-                m_widget->timeSlider->setEnabled(true);
+                timeBox->setEnabled(true);
+                timeSlider->setEnabled(true);
             }
             else
             {
-                m_widget->timeBox->setValue(100);
+                timeBox->setValue(100);
                 timeBox_valueChanged(100);
-                m_widget->timeBox->setEnabled(false);
-                m_widget->timeSlider->setEnabled(false);
+                timeBox->setEnabled(false);
+                timeSlider->setEnabled(false);
             }
             if (m_voiceList[index].pitchAdjustable)
             {
-                m_widget->frequencyBox->setEnabled(true);
-                m_widget->frequencySlider->setEnabled(true);
+                frequencyBox->setEnabled(true);
+                frequencySlider->setEnabled(true);
             }
             else
             {
-                m_widget->frequencyBox->setValue(100);
+                frequencyBox->setValue(100);
                 frequencyBox_valueChanged(100);
-                m_widget->frequencyBox->setEnabled(false);
-                m_widget->frequencySlider->setEnabled(false);
+                frequencyBox->setEnabled(false);
+                frequencySlider->setEnabled(false);
             }
             if ((int)index != currentVoiceIndex) configChanged();
         }
@@ -395,34 +386,36 @@ bool FestivalIntConf::readXmlBool(QDomNode &node, const QString &elementName, bo
 
 void FestivalIntConf::scanVoices()
 {
-    // kdDebug() << "FestivalIntConf::scanVoices: Running" << endl;
+    // kDebug() << "FestivalIntConf::scanVoices: Running";
     // Get existing voice code (if any).
     QString currentVoiceCode;
-    int index = m_widget->selectVoiceCombo->currentItem();
-    if (index < (int)m_voiceList.count()) currentVoiceCode = m_voiceList[index].code;
+    int index = selectVoiceCombo->currentIndex();
+    if (index >= 0 && index < m_voiceList.count()) currentVoiceCode = m_voiceList[index].code;
 
     m_voiceList.clear();
-    m_widget->selectVoiceCombo->clear();
-    m_widget->selectVoiceCombo->insertItem(i18n("Scanning... Please wait."));
+    selectVoiceCombo->clear();
+    selectVoiceCombo->addItem(i18n("Scanning... Please wait."));
 
     // Save current state of selectVoiceCombo box and disable.
-    bool selectVoiceComboEnabled = m_widget->selectVoiceCombo->isEnabled();
-    m_widget->selectVoiceCombo->setEnabled(false);
+    bool selectVoiceComboEnabled = selectVoiceCombo->isEnabled();
+    selectVoiceCombo->setEnabled(false);
 
     // Clear existing list of supported voice codes.
     // m_supportedVoiceCodes.clear();
-    m_widget->selectVoiceCombo->clear();
+    selectVoiceCombo->clear();
 
-    QString exePath = realFilePath(m_widget->festivalPath->url());
+    QString exePath = realFilePath(festivalPath->url().path());
     if (!getLocation(exePath).isEmpty())
     {
         // Set up a progress dialog.
-        m_progressDlg = new KProgressDialog(m_widget, "kttsmgr_queryvoices",
+        m_progressDlg = new KProgressDialog(this,
             i18n("Query Voices"),
-            i18n("Querying Festival for available voices.  This could take up to 15 seconds."),
-            true);
+            i18n("Querying Festival for available voices.  This could take up to 15 seconds."));
+        m_progressDlg->setModal(true);
         m_progressDlg->progressBar()->hide();
         m_progressDlg->setAllowCancel(true);
+        // TODO: This is a bug workaround.  Remove when no longer needed.
+        m_progressDlg->setDefaultButton(KDialog::Cancel);
 
         // Create Festival process and request a list of voice codes.
         if (m_festProc)
@@ -438,7 +431,7 @@ void FestivalIntConf::scanVoices()
 
         // Display progress dialog modally.
         m_progressDlg->exec();
-        // kdDebug() << "FestivalIntConf::scanVoices: back from progressDlg->exec()" << endl;
+        // kDebug() << "FestivalIntConf::scanVoices: back from progressDlg->exec()";
 
         // Processing continues until either user clicks Cancel button, or until
         // Festival responds with the list.  When Festival responds with list,
@@ -456,27 +449,28 @@ void FestivalIntConf::scanVoices()
     {
         // User's desktop language setting.
         QString desktopLanguageCode = KGlobal::locale()->language();
-        QString twoAlpha;
+        QString langAlpha;
         QString countryCode;
+        QString modifier;
         QString charSet;
-        KGlobal::locale()->splitLocale(desktopLanguageCode, twoAlpha, countryCode, charSet);
-        desktopLanguageCode = twoAlpha.lower();
+        KGlobal::locale()->splitLocale(desktopLanguageCode, langAlpha, countryCode, modifier, charSet);
+        desktopLanguageCode = langAlpha.toLower();
 
         // Festival known voices list.
         QString voicesFilename = KGlobal::dirs()->resourceDirs("data").last() + "/kttsd/festivalint/voices";
         QDomDocument voicesDoc("Festival Voices");
         QFile voicesFile(voicesFilename);
-        if (voicesFile.open(IO_ReadOnly)) voicesDoc.setContent(&voicesFile);
+        if (voicesFile.open(QIODevice::ReadOnly)) voicesDoc.setContent(&voicesFile);
         voicesFile.close();
         QDomNodeList voices = voicesDoc.elementsByTagName("voice");
         uint voicesCount = voices.count();
         if (voicesCount == 0)
-            kdDebug() << "FestivalIntConf::scanVoices: Unable to open " << voicesFilename << ".  Is KDEDIR defined?" << endl;
+            kDebug() << "FestivalIntConf::scanVoices: Unable to open " << voicesFilename << ".  Is KDEDIR defined?";
 
         // Iterate thru list of voice codes returned by Festival,
         // find matching entry in voices.xml file, and add to list of supported voices.
-        QPixmap maleIcon = KGlobal::iconLoader()->loadIcon("male", KIcon::Small);
-        QPixmap femaleIcon = KGlobal::iconLoader()->loadIcon("female", KIcon::Small);
+        KIcon maleIcon("male");
+        KIcon femaleIcon("female");
         QStringList::ConstIterator itEnd = m_supportedVoiceCodes.constEnd();
         for(QStringList::ConstIterator it = m_supportedVoiceCodes.begin(); it != itEnd; ++it )
         {
@@ -485,15 +479,15 @@ void FestivalIntConf::scanVoices()
             for (uint index=0; index < voicesCount; ++index)
             {
                 QDomNode voiceNode = voices.item(index);
-                QString voiceCode = readXmlString(voiceNode, "code", QString::null);
-                // kdDebug() << "FestivalIntConf::scanVoices: Comparing code " << code << " to " << voiceCode << endl;
+                QString voiceCode = readXmlString(voiceNode, "code", QString());
+                // kDebug() << "FestivalIntConf::scanVoices: Comparing code " << code << " to " << voiceCode;
                 if (voiceCode == code)
                 {
                     found = true;
                     voiceStruct voiceTemp;
                     voiceTemp.code = code;
-                    voiceTemp.name = i18n("FestivalVoiceName",
-                        readXmlString(voiceNode, "name", "Unknown").utf8());
+                    voiceTemp.name = i18nc("FestivalVoiceName",
+                        readXmlString(voiceNode, "name", "Unknown").toUtf8());
                     voiceTemp.languageCode = readXmlString(voiceNode, "language", m_languageCode);
                     voiceTemp.codecName = readXmlString(voiceNode, "codec", "ISO 8859-1");
                     voiceTemp.gender = readXmlString(voiceNode, "gender", "neutral");
@@ -502,13 +496,13 @@ void FestivalIntConf::scanVoices()
                     voiceTemp.rateAdjustable = readXmlBool(voiceNode, "rate-adjustable", true);
                     voiceTemp.pitchAdjustable = readXmlBool(voiceNode, "pitch-adjustable", true);
                     m_voiceList.append(voiceTemp);
-                    QString voiceDisplayName = voiceTemp.name + " (" + voiceTemp.code + ")";
+                    QString voiceDisplayName = voiceTemp.name + " (" + voiceTemp.code + ')';
                     if (voiceTemp.gender == "male")
-                        m_widget->selectVoiceCombo->insertItem(maleIcon, voiceDisplayName);
+                        selectVoiceCombo->addItem(maleIcon, voiceDisplayName);
                     else if (voiceTemp.gender == "female")
-                        m_widget->selectVoiceCombo->insertItem(femaleIcon, voiceDisplayName);
+                        selectVoiceCombo->addItem(femaleIcon, voiceDisplayName);
                     else
-                        m_widget->selectVoiceCombo->insertItem(voiceDisplayName);
+                        selectVoiceCombo->addItem(voiceDisplayName);
                     break;
                 }
             }
@@ -525,27 +519,27 @@ void FestivalIntConf::scanVoices()
                 voiceTemp.rateAdjustable = true;
                 voiceTemp.pitchAdjustable = true;
                 m_voiceList.append(voiceTemp);
-                m_widget->selectVoiceCombo->insertItem(voiceTemp.name + " (" + voiceTemp.code + ")");
+                selectVoiceCombo->addItem(voiceTemp.name + " (" + voiceTemp.code + ')');
             }
         }
-        m_widget->selectVoiceCombo->setEnabled(true);
-    } else kdDebug() << "FestivalIntConf::scanVoices: No voices found" << endl;
+        selectVoiceCombo->setEnabled(true);
+    } else kDebug() << "FestivalIntConf::scanVoices: No voices found";
     setDefaultVoice(voiceCodeToListIndex(currentVoiceCode));
     // Emit configChanged if the enabled state of the selectVoiceCombo has changed.
     // This occurs when user changes Festival EXE path, then clicks Rescan.
-    if (selectVoiceComboEnabled != m_widget->selectVoiceCombo->isEnabled()) configChanged();
+    if (selectVoiceComboEnabled != selectVoiceCombo->isEnabled()) configChanged();
 }
 
 void FestivalIntConf::slotQueryVoicesFinished(const QStringList &voiceCodes)
 {
-    // kdDebug() << "FestivalIntConf::slotQueryVoicesFinished: voiceCodes.count() = " << voiceCodes.count() << endl;
+    // kDebug() << "FestivalIntConf::slotQueryVoicesFinished: voiceCodes.count() = " << voiceCodes.count();
     m_supportedVoiceCodes = voiceCodes;
     if (m_progressDlg) m_progressDlg->close();
 }
 
 void FestivalIntConf::slotTest_clicked()
 {
-    // kdDebug() << "FestivalIntConf::slotTest_clicked: Running " << endl;
+    // kDebug() << "FestivalIntConf::slotTest_clicked: Running ";
     // If currently synthesizing, stop it.
     if (m_festProc)
         m_festProc->stopText();
@@ -555,41 +549,46 @@ void FestivalIntConf::slotTest_clicked()
         connect (m_festProc, SIGNAL(stopped()), this, SLOT(slotSynthStopped()));
     }
     // Create a temp file name for the wave file.
-    KTempFile tempFile (locateLocal("tmp", "festivalintplugin-"), ".wav");
-    QString tmpWaveFile = tempFile.file()->name();
-    tempFile.close();
+    KTemporaryFile *tempFile = new KTemporaryFile();
+    tempFile->setPrefix("festivalintplugin-");
+    tempFile->setSuffix(".wav");
+    tempFile->open();
+    QString tmpWaveFile = tempFile->fileName();
+    delete tempFile;
+
+    kDebug() << "FestivalIntConf::slotTest_clicked: tmpWaveFile = " << tmpWaveFile;
 
     // Get the code for the selected voice.
-    QString voiceCode = m_voiceList[m_widget->selectVoiceCombo->currentItem()].code;
+    QString voiceCode = m_voiceList[selectVoiceCombo->currentIndex()].code;
 
     // Get language code for the selected voice.
-    QString languageCode = m_voiceList[m_widget->selectVoiceCombo->currentItem()].languageCode;
+    QString languageCode = m_voiceList[selectVoiceCombo->currentIndex()].languageCode;
 
     // Get test message in the language of the voice.
     QString testMsg = testMessage(languageCode);
 
     // Get codec.
     QTextCodec* codec = PlugInProc::codecIndexToCodec(
-        m_widget->characterCodingBox->currentItem(), m_codecList);
+        characterCodingBox->currentIndex(), m_codecList);
 
     // Tell user to wait.
-    m_progressDlg = new KProgressDialog(m_widget, "ktts_festivalint_testdlg",
+    m_progressDlg = new KProgressDialog(this,
         i18n("Testing"),
-        i18n("Testing.  MultiSyn voices require several seconds to load.  Please be patient."),
-        true);
+        i18n("Testing.  MultiSyn voices require several seconds to load.  Please be patient."));
+    m_progressDlg->setModal(true);
     m_progressDlg->progressBar()->hide();
     m_progressDlg->setAllowCancel(true);
 
-    // kdDebug() << "FestivalIntConf::slotTest_clicked: calling synth with voiceCode: " << voiceCode << " time percent: " << m_widget->timeBox->value() << endl;
+    // kDebug() << "FestivalIntConf::slotTest_clicked: calling synth with voiceCode: " << voiceCode << " time percent: " << timeBox->value();
     connect (m_festProc, SIGNAL(synthFinished()), this, SLOT(slotSynthFinished()));
     m_festProc->synth(
-        realFilePath(m_widget->festivalPath->url()),
+        realFilePath(festivalPath->url().path()),
         testMsg,
         tmpWaveFile,
         voiceCode,
-        m_widget->timeBox->value(),
-        m_widget->frequencyBox->value(),
-        m_widget->volumeBox->value(),
+        timeBox->value(),
+        frequencyBox->value(),
+        volumeBox->value(),
         languageCode,
         codec);
 
@@ -604,7 +603,7 @@ void FestivalIntConf::slotTest_clicked()
 
 void FestivalIntConf::slotSynthFinished()
 {
-    // kdDebug() << "FestivalIntConf::slotSynthFinished: Running" << endl;
+    // kDebug() << "FestivalIntConf::slotSynthFinished: Running";
     // If user canceled, progress dialog is gone, so exit.
     if (!m_progressDlg)
     {
@@ -621,7 +620,7 @@ void FestivalIntConf::slotSynthFinished()
     // Player object deletes the wave file when done.
     if (m_player) m_player->play(m_waveFile);
     QFile::remove(m_waveFile);
-    m_waveFile = QString::null;
+    m_waveFile.clear();
     if (m_progressDlg) m_progressDlg->close();
 }
 
@@ -629,63 +628,63 @@ void FestivalIntConf::slotSynthStopped()
 {
     // Clean up after canceling test.
     QString filename = m_festProc->getFilename();
-    // kdDebug() << "FestivalIntConf::slotSynthStopped: filename = " << filename << endl;
+    // kDebug() << "FestivalIntConf::slotSynthStopped: filename = " << filename;
     if (!filename.isNull()) QFile::remove(filename);
 }
 
 void FestivalIntConf::slotFestivalPath_textChanged()
 {
-    QString exePath = realFilePath(m_widget->festivalPath->url());
-    m_widget->selectVoiceCombo->setEnabled(false);
+    QString exePath = realFilePath(festivalPath->url().path());
+    selectVoiceCombo->setEnabled(false);
     if (!exePath.isEmpty() && !getLocation(exePath).isEmpty())
     {
-        m_widget->rescan->setEnabled(true);
-    } else m_widget->rescan->setEnabled(false);
+        rescan->setEnabled(true);
+    } else rescan->setEnabled(false);
 }
 
 void FestivalIntConf::slotSelectVoiceCombo_activated()
 {
-    int index = m_widget->selectVoiceCombo->currentItem();
+    int index = selectVoiceCombo->currentIndex();
     QString codecName = m_voiceList[index].codecName;
     int codecNdx = PlugInProc::codecNameToListIndex(codecName, m_codecList);
-    m_widget->characterCodingBox->setCurrentItem(codecNdx);
-    m_widget->preloadCheckBox->setChecked(
+    characterCodingBox->setCurrentIndex(codecNdx);
+    preloadCheckBox->setChecked(
         m_voiceList[index].preload);
     if (m_voiceList[index].volumeAdjustable)
     {
-        m_widget->volumeBox->setEnabled(true);
-        m_widget->volumeSlider->setEnabled(true);
+        volumeBox->setEnabled(true);
+        volumeSlider->setEnabled(true);
     }
     else
     {
-        m_widget->volumeBox->setValue(100);
+        volumeBox->setValue(100);
         volumeBox_valueChanged(100);
-        m_widget->volumeBox->setEnabled(false);
-        m_widget->volumeSlider->setEnabled(false);
+        volumeBox->setEnabled(false);
+        volumeSlider->setEnabled(false);
     }
     if (m_voiceList[index].rateAdjustable)
     {
-        m_widget->timeBox->setEnabled(true);
-        m_widget->timeSlider->setEnabled(true);
+        timeBox->setEnabled(true);
+        timeSlider->setEnabled(true);
     }
     else
     {
-        m_widget->timeBox->setValue(100);
+        timeBox->setValue(100);
         timeBox_valueChanged(100);
-        m_widget->timeBox->setEnabled(false);
-        m_widget->timeSlider->setEnabled(false);
+        timeBox->setEnabled(false);
+        timeSlider->setEnabled(false);
     }
     if (m_voiceList[index].pitchAdjustable)
     {
-        m_widget->frequencyBox->setEnabled(true);
-        m_widget->frequencySlider->setEnabled(true);
+        frequencyBox->setEnabled(true);
+        frequencySlider->setEnabled(true);
     }
     else
     {
-        m_widget->frequencyBox->setValue(100);
+        frequencyBox->setValue(100);
         frequencyBox_valueChanged(100);
-        m_widget->frequencyBox->setEnabled(false);
-        m_widget->frequencySlider->setEnabled(false);
+        frequencyBox->setEnabled(false);
+        frequencySlider->setEnabled(false);
     }
 }
 
@@ -706,25 +705,25 @@ int FestivalIntConf::sliderToPercent(int sliderValue) {
 }
 
 void FestivalIntConf::volumeBox_valueChanged(int percentValue) {
-    m_widget->volumeSlider->setValue(percentToSlider(percentValue));
+    volumeSlider->setValue(percentToSlider(percentValue));
 }
 
 void FestivalIntConf::timeBox_valueChanged(int percentValue) {
-    m_widget->timeSlider->setValue (percentToSlider (percentValue));
+    timeSlider->setValue (percentToSlider (percentValue));
 }
 
 void FestivalIntConf::frequencyBox_valueChanged(int percentValue) {
-    m_widget->frequencySlider->setValue(percentToSlider(percentValue));
+    frequencySlider->setValue(percentToSlider(percentValue));
 }
 
 void FestivalIntConf::volumeSlider_valueChanged(int sliderValue) {
-    m_widget->volumeBox->setValue(sliderToPercent(sliderValue));
+    volumeBox->setValue(sliderToPercent(sliderValue));
 }
 
 void FestivalIntConf::timeSlider_valueChanged(int sliderValue) {
-    m_widget->timeBox->setValue (sliderToPercent (sliderValue));
+    timeBox->setValue (sliderToPercent (sliderValue));
 }
 
 void FestivalIntConf::frequencySlider_valueChanged(int sliderValue) {
-    m_widget->frequencyBox->setValue(sliderToPercent(sliderValue));
+    frequencyBox->setValue(sliderToPercent(sliderValue));
 }
